% Auto-generated chapter 46 for nasai
% Hadiths in this chapter: 115

\hadithdefcmd{nasai}{4870}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا شُعَيْبُ بْنُ اللَّيْثِ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنِ الْقَعْقَاعِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَزْنِي الزَّانِي حِينَ يَزْنِي وَهُوَ مُؤْمِنٌ وَلاَ يَسْرِقُ السَّارِقُ حِينَ يَسْرِقُ وَهُوَ مُؤْمِنٌ وَلاَ يَشْرَبُ الْخَمْرَ حِينَ يَشْرَبُهَا وَهُوَ مُؤْمِنٌ وَلاَ يَنْتَهِبُ نُهْبَةً ذَاتَ شَرَفٍ يَرْفَعُ النَّاسُ إِلَيْهَا أَبْصَارَهُمْ وَهُوَ مُؤْمِنٌ ‏"‏ ‏.‏\hadithno{4870}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from abu Hurairah that the Messenger of Allah said:"No one who commits Zina is a believer at the moment when he is committing Zina; no one who steals is a believe at the moment when he is stealing; no one who drinks wine is a believer at the moment when he is drinking it; and no robber is a believer at the moment when he is robbing and the people are looking on}}
\hadithdefcmd{nasai}{4871}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، ح وَأَنْبَأَنَا أَحْمَدُ بْنُ سَيَّارٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُثْمَانَ، عَنْ أَبِي حَمْزَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم وَقَالَ أَحْمَدُ فِي حَدِيثِهِ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَزْنِي الزَّانِي حِينَ يَزْنِي وَهُوَ مُؤْمِنٌ وَلاَ يَسْرِقُ حِينَ يَسْرِقُ وَهُوَ مُؤْمِنٌ وَلاَ يَشْرَبُ الْخَمْرَ حِينَ يَشْرَبُ وَهُوَ مُؤْمِنٌ ثُمَّ التَّوْبَةُ مَعْرُوضَةٌ بَعْدُ ‏"‏ ‏.‏\hadithno{4871}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from abu Hurairah that the Prophet - and Ahmad said in his Hadith:"The Messenger of Allah said: 'No one who commits Zina is a believer at the moment when he is committing Zina; no one who steals is a believer at the moment when he is stealing; no one who drinks wine is a believer at the moment when he is drinking it; but repentance is available to him after that}}
\hadithdefcmd{nasai}{4872}{أَخْبَرَنَا مُحَمَّدُ بْنُ يَحْيَى الْمَرْوَزِيُّ أَبُو عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُثْمَانَ، عَنْ أَبِي حَمْزَةَ، عَنْ يَزِيدَ، - وَهُوَ ابْنُ أَبِي زِيَادٍ - عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ لاَ يَزْنِي الزَّانِي حِينَ يَزْنِي وَهُوَ مُؤْمِنٌ وَلاَ يَسْرِقُ وَهُوَ مُؤْمِنٌ وَلاَ يَشْرَبُ الْخَمْرَ وَهُوَ مُؤْمِنٌ وَذَكَرَ رَابِعَةً فَنَسِيتُهَا فَإِذَا فَعَلَ ذَلِكَ خَلَعَ رِبْقَةَ الإِسْلاَمِ مِنْ عُنُقِهِ فَإِنْ تَابَ تَابَ اللَّهُ عَلَيْهِ ‏.‏\hadithno{4872}\hadithgrade{Abu Ghuddah: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"No one who commits Zina is a believer at the moment when he is committing Zina; no one who steals is a believer at the moment when he is stealing; no one who drinks wine is a believer at the moment when he is drinking it." - And he mentioned a fourth but I (the narrator) have forgotten it - "When he does that the yoke of Islam is shed from his neck, but if he repents, Allah accepts his repentance}}
\hadithdefcmd{nasai}{4873}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ الْمُخَرِّمِيُّ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، قَالَ حَدَّثَنَا الأَعْمَشُ، ح وَأَنْبَأَنَا أَحْمَدُ بْنُ حَرْبٍ، عَنْ أَبِي مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَعَنَ اللَّهُ السَّارِقَ يَسْرِقُ الْبَيْضَةَ فَتُقْطَعُ يَدُهُ وَيَسْرِقُ الْحَبْلَ فَتُقْطَعُ يَدُهُ ‏"‏ ‏.‏\hadithno{4873}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah, may Allah be pleased with him, said:"The Messenger of Allah said; 'Allah curses the thief who steals an egg and had his hand cut off, and who steals a rope and has his hand cut off}}
\hadithdefcmd{nasai}{4874}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا بَقِيَّةُ بْنُ الْوَلِيدِ، قَالَ حَدَّثَنِي صَفْوَانُ بْنُ عَمْرٍو، قَالَ حَدَّثَنِي أَزْهَرُ بْنُ عَبْدِ اللَّهِ الْحَرَازِيُّ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، أَنَّهُ رَفَعَ إِلَيْهِ نَفَرٌ مِنَ الْكَلاَعِيِّينَ أَنَّ حَاكَةً سَرَقُوا مَتَاعًا فَحَبَسَهُمْ أَيَّامًا ثُمَّ خَلَّى سَبِيلَهُمْ فَأَتَوْهُ فَقَالُوا خَلَّيْتَ سَبِيلَ هَؤُلاَءِ بِلاَ امْتِحَانٍ وَلاَ ضَرْبٍ ‏.‏ فَقَالَ النُّعْمَانُ مَا شِئْتُمْ إِنْ شِئْتُمْ أَضْرِبْهُمْ فَإِنْ أَخْرَجَ اللَّهُ مَتَاعَكُمْ فَذَاكَ وَإِلاَّ أَخَذْتُ مِنْ ظُهُورِكُمْ مِثْلَهُ ‏.‏ قَالُوا هَذَا حُكْمُكَ ‏.‏ قَالَ هَذَا حُكْمُ اللَّهِ عَزَّ وَجَلَّ وَرَسُولِهِ صلى الله عليه وسلم ‏.‏\hadithno{4874}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from An-Nu'man bin Bashir that:a group of the Kala'iyin complaned to him about some people who had stolen some goods, shoe detained them for several days, and then he let them go. They came and said: "You let them go without any pressure (to make them admit to their crime) or beating?" An-Nu'man said: "What do you want? If you wish, I will beat them, and if Allah brings back your goods thereby, all well and good. Otherwise I will take retaliation from your backs (by beating you) likewise." They said: "is this your ruling?" He said: "This is the ruling of Allah and His Messenger "(Daif)}}
\hadithdefcmd{nasai}{4875}{أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ مُحَمَّدِ بْنِ سَلاَّمٍ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، قَالَ أَخْبَرَنِي ابْنُ الْمُبَارَكِ، عَنْ مَعْمَرٍ، عَنْ بَهْزِ بْنِ حَكِيمٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حَبَسَ نَاسًا فِي تُهْمَةٍ ‏.‏\hadithno{4875}\hadithgrade{Abu Ghuddah: -; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Bahz bin Hakim, from his father, from his grandfather, that:the Messenger of Allah detained some people who were under suspicion}}
\hadithdefcmd{nasai}{4876}{أَخْبَرَنَا عَلِيُّ بْنُ سَعِيدِ بْنِ مَسْرُوقٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ مَعْمَرٍ، عَنْ بَهْزِ بْنِ حَكِيمٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حَبَسَ رَجُلاً فِي تُهْمَةٍ ثُمَّ خَلَّى سَبِيلَهُ ‏.‏\hadithno{4876}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Bahz bin Hakim, from his father, from his grandfather, that:the Messenger of Allah detained a man who was under suspicion, and then he let him go. (Hssan)}}
\hadithdefcmd{nasai}{4877}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَبِي الْمُنْذِرِ، مَوْلَى أَبِي ذَرٍّ عَنْ أَبِي أُمَيَّةَ الْمَخْزُومِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أُتِيَ بِلِصٍّ اعْتَرَفَ اعْتِرَافًا وَلَمْ يُوجَدْ مَعَهُ مَتَاعٌ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا إِخَالُكَ سَرَقْتَ ‏"‏ ‏.‏ قَالَ بَلَى ‏.‏ قَالَ ‏"‏ اذْهَبُوا بِهِ فَاقْطَعُوهُ ثُمَّ جِيئُوا بِهِ ‏"‏ ‏.‏ فَقَطَعُوهُ ثُمَّ جَاءُوا بِهِ فَقَالَ لَهُ ‏"‏ قُلْ أَسْتَغْفِرُ اللَّهَ وَأَتُوبُ إِلَيْهِ ‏"‏ ‏.‏ فَقَالَ أَسْتَغْفِرُ اللَّهَ وَأَتُوبُ إِلَيْهِ ‏.‏ قَالَ ‏"‏ اللَّهُمَّ تُبْ عَلَيْهِ ‏"‏ ‏.‏\hadithno{4877}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from abu Umayah Al-Makhzumi that:a thief who confused to a crime but with whom no stolen goods has been found, was brought to the Messenger of Allah. The Messenger of Allah said to him: "I do not think that you stole anything."He He said: "Yes I did." He said: "Take him and cut off his hands, then bring him here, "So they cut off his hand then they brought him to him. He said to him; "Say: I seek the forgiveness of Allah and I repent to Him." He said: "I seek the forgiveness of Allah and I repent to Him." He said:: "O Allah, accept his repentance."(Daif)}}
\hadithdefcmd{nasai}{4878}{أَخْبَرَنَا هِلاَلُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ عَطَاءٍ، عَنْ صَفْوَانَ بْنِ أُمَيَّةَ، أَنَّ رَجُلاً، سَرَقَ بُرْدَةً لَهُ فَرَفَعَهُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَمَرَ بِقَطْعِهِ فَقَالَ يَا رَسُولَ اللَّهِ قَدْ تَجَاوَزْتُ عَنْهُ ‏.‏ فَقَالَ ‏ "‏ أَبَا وَهْبٍ أَفَلاَ كَانَ قَبْلَ أَنْ تَأْتِيَنَا بِهِ ‏"‏ ‏.‏ فَقَطَعَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{4878}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Safwan bin Umayyah, that:a man stole a Burdah of his, so he brought him before the Messenger of Allah, who ordered that his hand be cut off. He said: "O Messenger of Allah, I will let him have it." He said: "Abu Wahb! Why didn't you do that before you brought him to us?" And the Messenger of Allah had (the man's) hand cut off}}
\hadithdefcmd{nasai}{4879}{أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ أَحْمَدَ بْنِ مُحَمَّدِ بْنِ حَنْبَلٍ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ عَطَاءٍ، عَنْ طَارِقِ بْنِ مُرَقَّعٍ، عَنْ صَفْوَانَ بْنِ أُمَيَّةَ، أَنَّ رَجُلاً، سَرَقَ بُرْدَةً فَرَفَعَهُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَمَرَ بِقَطْعِهِ فَقَالَ يَا رَسُولَ اللَّهِ قَدْ تَجَاوَزْتُ عَنْهُ ‏.‏ قَالَ ‏ "‏ فَلَوْلاَ كَانَ هَذَا قَبْلَ أَنْ تَأْتِيَنِي بِهِ يَا أَبَا وَهْبٍ ‏"‏ ‏.‏ فَقَطَعَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{4879}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Safwan bin Umayyah that:a man stole his Burdah, so he brought him before the Prophet, who ordered that his hand be cut off. He said: "O Messenger of Allah, I will let him have it." He said: "O Abu Wahb! Why didn't you do that before you brought him to me?" And the Messenger of Allah had (the man's) hand cut off}}
\hadithdefcmd{nasai}{4880}{أَخْبَرَنَا مُحَمَّدُ بْنُ حَاتِمِ بْنِ نُعَيْمٍ، قَالَ أَنْبَأَنَا حِبَّانُ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، عَنِ الأَوْزَاعِيِّ، قَالَ حَدَّثَنِي عَطَاءُ بْنُ أَبِي رَبَاحٍ، أَنَّ رَجُلاً، سَرَقَ ثَوْبًا فَأُتِيَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَمَرَ بِقَطْعِهِ فَقَالَ الرَّجُلُ يَا رَسُولَ اللَّهِ هُوَ لَهُ ‏.‏ قَالَ ‏ "‏ فَهَلاَّ قَبْلَ الآنَ ‏"‏ ‏.‏\hadithno{4880}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ata' bin Abi Rabah narrated that:a man stole a garment, and was brought before the Messenger of Allah, who order that his hand be cut off. The man said: "O Messenger of Allah, he can keep it." He said: "Why (did you not say that) before now?}}
\hadithdefcmd{nasai}{4881}{أَخْبَرَنِي هِلاَلُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا حُسَيْنٌ، قَالَ حَدَّثَنَا زُهَيْرٌ، قَالَ حَدَّثَنَا عَبْدُ الْمَلِكِ، - هُوَ ابْنُ أَبِي بَشِيرٍ - قَالَ حَدَّثَنِي عِكْرِمَةُ، عَنْ صَفْوَانَ بْنِ أُمَيَّةَ، أَنَّهُ طَافَ بِالْبَيْتِ وَصَلَّى ثُمَّ لَفَّ رِدَاءً لَهُ مِنْ بُرْدٍ فَوَضَعَهُ تَحْتَ رَأْسِهِ فَنَامَ فَأَتَاهُ لِصٌّ فَاسْتَلَّهُ مِنْ تَحْتِ رَأْسِهِ فَأَخَذَهُ فَأَتَى بِهِ النَّبِيَّ صلى الله عليه وسلم فَقَالَ إِنَّ هَذَا سَرَقَ رِدَائِي ‏.‏ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَسَرَقْتَ رِدَاءَ هَذَا ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ اذْهَبَا بِهِ فَاقْطَعَا يَدَهُ ‏"‏ ‏.‏ قَالَ صَفْوَانُ مَا كُنْتُ أُرِيدُ أَنْ تُقْطَعَ يَدُهُ فِي رِدَائِي ‏.‏ فَقَالَ لَهُ ‏"‏ فَلَوْ مَا قَبْلَ هَذَا ‏"‏ ‏.‏ خَالَفَهُ أَشْعَثُ بْنُ سَوَّارٍ ‏.‏\hadithno{4881}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Safwan bin Umayyah that:he circumambulated theKa'bah and prayed, then he rolled up a Rid' of his and placed it beneath his head, and slept. A thief came and slid it out from beneath his head and took it. He brought him to the Prophet and said: "This man stole my Rida. The Prophet said to him: Did you steal this man's Rida?" He said: "Yes." He said: "Take him away and cut his hand off." Safwan said: "I* did not want to have his hand cut off for my Rida'." He said: "Why (did you not say that) before now?}}
\hadithdefcmd{nasai}{4882}{أَخْبَرَنَا مُحَمَّدُ بْنُ هِشَامٍ، - يَعْنِي ابْنَ أَبِي خِيَرَةَ - قَالَ حَدَّثَنَا الْفَضْلُ، - يَعْنِي ابْنَ الْعَلاَءِ الْكُوفِيَّ - قَالَ حَدَّثَنَا أَشْعَثُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ صَفْوَانُ نَائِمًا فِي الْمَسْجِدِ وَرِدَاؤُهُ تَحْتَهُ فَسُرِقَ فَقَامَ وَقَدْ ذَهَبَ الرَّجُلُ فَأَدْرَكَهُ فَأَخَذَهُ فَجَاءَ بِهِ إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَمَرَ بِقَطْعِهِ قَالَ صَفْوَانُ يَا رَسُولَ اللَّهِ مَا بَلَغَ رِدَائِي أَنْ يُقْطَعَ فِيهِ رَجُلٌ ‏.‏ قَالَ ‏ "‏ هَلاَّ كَانَ هَذَا قَبْلَ أَنْ تَأْتِيَنَا بِهِ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ أَشْعَثُ ضَعِيفٌ ‏.‏\hadithno{4882}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It narrated that Ibn 'Abbas said:"Safwina was slleping in the Masjid with his Rida' beneath him, and it was stolen. He got up, and the man had gone, but he caught up with him, and took him to the prophet, who ordered that his hand be cut off. Safwan said; 'O Messenger of Allah, my Rida 'is not worth cutting off a man's hand for. 'He said 'Why did you not say that before you brought him to me}}
\hadithdefcmd{nasai}{4883}{أَخْبَرَنِي أَحْمَدُ بْنُ عُثْمَانَ بْنِ حَكِيمٍ، قَالَ حَدَّثَنَا عَمْرٌو، عَنْ أَسْبَاطٍ، عَنْ سِمَاكٍ، عَنْ حُمَيْدِ بْنِ أُخْتِ، صَفْوَانَ عَنْ صَفْوَانَ بْنِ أُمَيَّةَ، قَالَ كُنْتُ نَائِمًا فِي الْمَسْجِدِ عَلَى خَمِيصَةٍ لِي ثَمَنُهَا ثَلاَثُونَ دِرْهَمًا فَجَاءَ رَجُلٌ فَاخْتَلَسَهَا مِنِّي فَأُخِذَ الرَّجُلُ فَأُتِيَ بِهِ النَّبِيُّ صلى الله عليه وسلم فَأَمَرَ بِهِ لِيُقْطَعَ فَأَتَيْتُهُ فَقُلْتُ أَتَقْطَعُهُ مِنْ أَجْلِ ثَلاَثِينَ دِرْهَمًا أَنَا أَبِيعُهُ وَأُنْسِئُهُ ثَمَنَهَا ‏.‏ قَالَ ‏ "‏ فَهَلاَّ كَانَ هَذَا قَبْلَ أَنْ تَأْتِيَنِي بِهِ ‏"‏ ‏.‏\hadithno{4883}\hadithgrade{Abu Ghuddah: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Hasan}\hadithtrans{It was knarrated that Safwan bin Umayyah said:"I was sleeping in the Masjid on a Khmaishah of mine that was worth thirty dirhams, and a man came and stole it from me. The man was caught and taken to the Prophet, who ordered that his hand be cut off. I came to him and said: "Will you cut off his hand for the sake of only thirty Dirhams? I will sell it to him on credit." He said:" Why did you not say this before you brought him to me?}}
\hadithdefcmd{nasai}{4884}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحِيمِ، قَالَ حَدَّثَنَا أَسَدُ بْنُ مُوسَى، قَالَ حَدَّثَنَا - وَذَكَرَ، - حَمَّادُ بْنُ سَلَمَةَ عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ طَاوُسٍ، عَنْ صَفْوَانَ بْنِ أُمَيَّةَ، أَنَّهُ سُرِقَتْ خَمِيصَتُهُ مِنْ تَحْتِ رَأْسِهِ وَهُوَ نَائِمٌ فِي مَسْجِدِ النَّبِيِّ صلى الله عليه وسلم فَأَخَذَ اللِّصَّ فَجَاءَ بِهِ إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَمَرَ بِقَطْعِهِ فَقَالَ صَفْوَانُ أَتَقْطَعُهُ قَالَ ‏ "‏ فَهَلاَّ قَبْلَ أَنْ تَأْتِيَنِي بِهِ تَرَكْتَهُ ‏"‏ ‏.‏\hadithno{4884}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Safwan bin Umayyah that:a Khamisah was stolen from beneath his head while he slept in the Masjid of the Prophet. He caught there thief and brought him to the Prophet, who ordered that his hand be cut off. Safwan said: "Are you going to cut off his hand?" He said "Why didn't you let him go before you b brought him to me?" (Daif)}}
\hadithdefcmd{nasai}{4885}{أَخْبَرَنَا مُحَمَّدُ بْنُ هَاشِمٍ، قَالَ حَدَّثَنَا الْوَلِيدُ، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ تَعَافَوُا الْحُدُودَ قَبْلَ أَنْ تَأْتُونِي بِهِ فَمَا أَتَانِي مِنْ حَدٍّ فَقَدْ وَجَبَ ‏"‏ ‏.‏\hadithno{4885}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated form 'Amr bin Shu'ainb, from his father, from his grandfather, that the Prophet said:"Pardon matters that may deserve a Hadd punishment before you bring it to my attention, for whatever is brought to my attention, the Hadd punishment becomes binding." (Saif)}}
\hadithdefcmd{nasai}{4886}{قَالَ الْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ وَهْبٍ، قَالَ سَمِعْتُ ابْنَ جُرَيْجٍ، يُحَدِّثُ عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ تَعَافَوُا الْحُدُودَ فِيمَا بَيْنَكُمْ فَمَا بَلَغَنِي مِنْ حَدٍّ فَقَدْ وَجَبَ ‏"‏ ‏.‏\hadithno{4886}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Amr bin Shu'aib from his father, from' Abdullah bin 'Amr that the Messenger of Allah said:"Pardon matters among yourselves that may deserve a Hadd punishment, for whatever is brought to my attention, the Hadd punishment b becomes binding." (Daif)}}
\hadithdefcmd{nasai}{4887}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، رضى الله عنهما أَنَّ امْرَأَةً، مَخْزُومِيَّةً كَانَتْ تَسْتَعِيرُ الْمَتَاعَ فَتَجْحَدُهُ فَأَمَرَ النَّبِيُّ صلى الله عليه وسلم بِقَطْعِ يَدِهَا ‏.‏\hadithno{4887}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Umar, may Allah be pleased with them both, that a Makhzumi woman used to borrow things then deny that she had borrowed them, so the Prophet (ﷺ) ordered that her hand be cut off}}
\hadithdefcmd{nasai}{4888}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، رضى الله عنهما قَالَ كَانَتِ امْرَأَةٌ مَخْزُومِيَّةٌ تَسْتَعِيرُ مَتَاعًا عَلَى أَلْسِنَةِ جَارَاتِهَا وَتَجْحَدُهُ فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِقَطْعِ يَدِهَا ‏.‏\hadithno{4888}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Umar, may Allah be pleased with them said:"There was a Makhzumi woman who used to borrow things, saying that her neighbors needed the, then she would deny that she had borrowed the, so the Messenger of Allah ordered that her hand be cut off}}
\hadithdefcmd{nasai}{4889}{أَخْبَرَنَا عُثْمَانُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي الْحَسَنُ بْنُ حَمَّادٍ، قَالَ حَدَّثَنَا عَمْرُو بْنُ هَاشِمٍ الْجَنْبِيُّ أَبُو مَالِكٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، رضى الله عنهما أَنَّ امْرَأَةً، كَانَتْ تَسْتَعِيرُ الْحُلِيَّ لِلنَّاسِ ثُمَّ تُمْسِكُهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لِتَتُبْ هَذِهِ الْمَرْأَةُ إِلَى اللَّهِ وَرَسُولِهِ وَتَرُدَّ مَا تَأْخُذُ عَلَى الْقَوْمِ ‏"‏ ‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قُمْ يَا بِلاَلُ فَخُذْ بِيَدِهَا فَاقْطَعْهَا ‏"‏ ‏.‏\hadithno{4889}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Umar, may Allah be pleased with them both, that:a woman used, to borrow jewelry from people then keep it. The Messenger of Allah said: "Let this woman repent to Allah and His Messenger and give back to people what she has taken." Then the Messenge of Allah said "Get up, O Bilal, take her hand and cut it off}}
\hadithdefcmd{nasai}{4890}{أَخْبَرَنِي مُحَمَّدُ بْنُ الْخَلِيلِ، عَنْ شُعَيْبِ بْنِ إِسْحَاقَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، أَنَّ امْرَأَةً، كَانَتْ تَسْتَعِيرُ الْحُلِيَّ فِي زَمَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَاسْتَعَارَتْ مِنْ ذَلِكَ حُلِيًّا فَجَمَعَتْهُ ثُمَّ أَمْسَكَتْهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لِتَتُبْ هَذِهِ الْمَرْأَةُ وَتُؤَدِّي مَا عِنْدَهَا ‏"‏ ‏.‏ مِرَارًا فَلَمْ تَفْعَلْ فَأَمَرَ بِهَا فَقُطِعَتْ ‏.‏\hadithno{4890}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Nafi that:a woman used to borrow jewelry during the time of the Messenger of Allah. She borrowed some jewelry, collected it and kept it. The Messenger of Allah said: "Let this woman repent and give back what she has," several times, but she did not do that, so he ordered that her hand be cut off}}
\hadithdefcmd{nasai}{4891}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَعْدَانَ بْنِ عِيسَى، قَالَ حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، قَالَ حَدَّثَنَا مَعْقِلٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ امْرَأَةً، مِنْ بَنِي مَخْزُومٍ سَرَقَتْ فَأُتِيَ بِهَا النَّبِيُّ صلى الله عليه وسلم فَعَاذَتْ بِأُمِّ سَلَمَةَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لَوْ كَانَتْ فَاطِمَةَ بِنْتَ مُحَمَّدٍ لَقَطَعْتُ يَدَهَا ‏"‏ ‏.‏ فَقُطِعَتْ يَدُهَا ‏.‏\hadithno{4891}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir that:a woman from Banu Makhzum stole (something), and she was brought to the Prophet. She sought the protection of Umm Salamah, but the Prophet said: "If Fatimah bint Muhammad were to steal, I would cut off her hand." And he ordered that her hand be cut off}}
\hadithdefcmd{nasai}{4892}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ سَعِيدِ بْنِ يَزِيدَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ امْرَأَةً، مِنْ بَنِي مَخْزُومٍ اسْتَعَارَتْ حُلِيًّا عَلَى لِسَانِ أُنَاسٍ فَجَحَدَتْهَا فَأَمَرَ بِهَا النَّبِيُّ صلى الله عليه وسلم فَقُطِعَتْ ‏.‏\hadithno{4892}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Saeed bin AL-Musayyab that:a woman from Banu Makhzum borrowed some jewelry, asking on behalf of others, then she denied (having done) that, and the Prophet ordered that her hand be cut off}}
\hadithdefcmd{nasai}{4893}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا عَبْدُ الصَّمَدِ، قَالَ حَدَّثَنَا هَمَّامٌ، قَالَ حَدَّثَنَا قَتَادَةُ، عَنْ دَاوُدَ بْنِ أَبِي عَاصِمٍ، أَنَّ سَعِيدَ بْنَ الْمُسَيَّبِ، حَدَّثَهُ نَحْوَهُ، ‏.‏\hadithno{4893}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Dawud bin Abi Asim that:Saeed bin Al-Musayyb narrated something similar to that}}
\hadithdefcmd{nasai}{4894}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا سُفْيَانُ، قَالَ كَانَتْ مَخْزُومِيَّةٌ تَسْتَعِيرُ مَتَاعًا وَتَجْحَدُهُ فَرُفِعَتْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَكُلِّمَ فِيهَا فَقَالَ ‏ "‏ لَوْ كَانَتْ فَاطِمَةَ لَقَطَعْتُ يَدَهَا ‏"‏ ‏.‏ قِيلَ لِسُفْيَانَ مَنْ ذَكَرَهُ قَالَ أَيُّوبُ بْنُ مُوسَى عَنِ الزُّهْرِيِّ عَنْ عُرْوَةَ عَنْ عَائِشَةَ إِنْ شَاءَ اللَّهُ تَعَالَى ‏.‏\hadithno{4894}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Sufyan said:"There was a Makhzumi woman who used to borrow things then deny that. She was brought to the Messenger of Allah and he was told about her. He said: 'If it were Fatimah (who stole), I would cut off her hand."' It was said to Sufyan: "Who told you that?" He said: "Ayyub bin Musa, from Az-Zuhri, from 'Urwah, from 'Aishah, if Allah the mighty and Sublime, wills}}
\hadithdefcmd{nasai}{4895}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ بْنِ مُوسَى، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ امْرَأَةً، سَرَقَتْ فَأُتِيَ بِهَا النَّبِيُّ صلى الله عليه وسلم فَقَالُوا مَنْ يَجْتَرِئُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم إِلاَّ أَنْ يَكُونَ أُسَامَةَ فَكَلَّمُوا أُسَامَةَ فَكَلَّمَهُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ يَا أُسَامَةُ إِنَّمَا هَلَكَتْ بَنُو إِسْرَائِيلَ حِينَ كَانُوا إِذَا أَصَابَ الشَّرِيفُ فِيهِمُ الْحَدَّ تَرَكُوهُ وَلَمْ يُقِيمُوا عَلَيْهِ وَإِذَا أَصَابَ الْوَضِيعُ أَقَامُوا عَلَيْهِ لَوْ كَانَتْ فَاطِمَةَ بِنْتَ مُحَمَّدٍ لَقَطَعْتُهَا ‏"‏ ‏.‏\hadithno{4895}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from `A'ishah that:A woman stole (something) and she was brought to the Prophet. They said: "Who would dare to speak to the Messenger of Allah except Usamah." So they spoke to Usamah and he spoke to (the Prophet). The Prophet said: "O Usamah, the Children of Israel were destroyed because whenever a noble person among them committed a crime, for which a Hadd punishment was deserved, they would let him go. But if a low-class person among them committed such a crime, they would carry out the punishment on him. If Fatimah bint Muhammad were to steal, I would cut off her hand}}
\hadithdefcmd{nasai}{4896}{أَخْبَرَنَا رِزْقُ اللَّهِ بْنُ مُوسَى، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ بْنِ مُوسَى، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ أُتِيَ النَّبِيُّ صلى الله عليه وسلم بِسَارِقٍ فَقَطَعَهُ قَالُوا مَا كُنَّا نُرِيدُ أَنْ يَبْلُغَ مِنْهُ هَذَا ‏.‏ قَالَ ‏ "‏ لَوْ كَانَتْ فَاطِمَةَ لَقَطَعْتُهَا ‏"‏ ‏.‏\hadithno{4896}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"A thief was brought to the hand." They said: "We did not think that you would take it so far." He said: "If it were Fatimah (who stole), I would cut off her hand}}
\hadithdefcmd{nasai}{4897}{أَخْبَرَنَا عَلِيُّ بْنُ سَعِيدِ بْنِ مَسْرُوقٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، عَنْ سُفْيَانَ بْنِ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ امْرَأَةً، سَرَقَتْ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالُوا مَا نُكَلِّمُهُ فِيهَا مَا مِنْ أَحَدٍ يُكَلِّمُهُ إِلاَّ حِبُّهُ أُسَامَةُ ‏.‏ فَكَلَّمَهُ فَقَالَ ‏ "‏ يَا أُسَامَةُ إِنَّ بَنِي إِسْرَائِيلَ هَلَكُوا بِمِثْلِ هَذَا كَانَ إِذَا سَرَقَ فِيهِمُ الشَّرِيفُ تَرَكُوهُ وَإِنْ سَرَقَ فِيهِمُ الدُّونُ قَطَعُوهُ وَإِنَّهَا لَوْ كَانَتْ فَاطِمَةَ بِنْتَ مُحَمَّدٍ لَقَطَعْتُهَا ‏"‏ ‏.‏\hadithno{4897}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah that:a woman stole at the time of Messenger of Allah and they said: "We cannot speak to him concerning her; there is no one who can speak to him except his beloved, Usamah." So he spoke to him, and he said"O Usamah, the Children of Israel were destroyed for such a thing. Whenever a noble person among them stole, they would let him go, but if a low-class person among them stole, they would cut off his hand. If it were Fatimah bint Muhammad (who stole), I would cut off her hand}}
\hadithdefcmd{nasai}{4898}{أَخْبَرَنَا عِمْرَانُ بْنُ بَكَّارٍ، قَالَ حَدَّثَنَا بِشْرُ بْنُ شُعَيْبٍ، قَالَ أَخْبَرَنِي أَبِي، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتِ اسْتَعَارَتِ امْرَأَةٌ عَلَى أَلْسِنَةِ أُنَاسٍ يُعْرَفُونَ - وَهِيَ لاَ تُعْرَفُ - حُلِيًّا فَبَاعَتْهُ وَأَخَذَتْ ثَمَنَهُ فَأُتِيَ بِهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَسَعَى أَهْلُهَا إِلَى أُسَامَةَ بْنِ زَيْدٍ فَكَلَّمَ رَسُولَ اللَّهِ صلى الله عليه وسلم فِيهَا فَتَلَوَّنَ وَجْهُ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ يُكَلِّمُهُ ثُمَّ قَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَتَشْفَعُ إِلَىَّ فِي حَدٍّ مِنْ حُدُودِ اللَّهِ ‏"‏ ‏.‏ فَقَالَ أُسَامَةُ اسْتَغْفِرْ لِي يَا رَسُولَ اللَّهِ ‏.‏ ثُمَّ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَشِيَّتَئِذٍ فَأَثْنَى عَلَى اللَّهِ عَزَّ وَجَلَّ بِمَا هُوَ أَهْلُهُ ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ فَإِنَّمَا هَلَكَ النَّاسُ قَبْلَكُمْ أَنَّهُمْ كَانُوا إِذَا سَرَقَ الشَّرِيفُ فِيهِمْ تَرَكُوهُ وَإِذَا سَرَقَ الضَّعِيفُ فِيهِمْ أَقَامُوا عَلَيْهِ الْحَدَّ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لَوْ أَنَّ فَاطِمَةَ بِنْتَ مُحَمَّدٍ سَرَقَتْ لَقَطَعْتُ يَدَهَا ‏"‏ ‏.‏ ثُمَّ قَطَعَ تِلْكَ الْمَرْأَةَ ‏.‏\hadithno{4898}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"A woman borrowed some jewelry, saying that other people whose names were known but hers was not then she sold it and kept the money. She was brought to the Messenger of Allah, and her people went to Usamah bin Zaid, who spoke to the Messenger of Allah concerning her. The face of ht Messenger of Allah changed color while he was speaking to him. Then the Messenger of Allah said to him: 'Are you interceding with me concerning one of ht Hadd punishments decreed by Allah?' Usamah said: 'Pray for forgiveness for me, O Messenger of Allah! Then the Messenger of Allah stood up that evening, he praised and glorified Allah, the mighty and sublime, as he deserves, then he said: 'The people who came before you were destroyed because, whenever a noble person among them stole, they let him go. But if a low-class person stole, they would carry out the punishment on him. By the One in whose hand is the soul of Muhammad, if Fatimah bint Muhammad were to steal, I would cut off her hand.' Then he cut off that woman}}
\hadithdefcmd{nasai}{4899}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ قُرَيْشًا، أَهَمَّهُمْ شَأْنُ الْمَخْزُومِيَّةِ الَّتِي سَرَقَتْ فَقَالُوا مَنْ يُكَلِّمُ فِيهَا رَسُولَ اللَّهِ صلى الله عليه وسلم قَالُوا وَمَنْ يَجْتَرِئُ عَلَيْهِ إِلاَّ أُسَامَةُ بْنُ زَيْدٍ حِبُّ رَسُولِ اللَّهِ صلى الله عليه وسلم فَكَلَّمَهُ أُسَامَةُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَتَشْفَعُ فِي حَدٍّ مِنْ حُدُودِ اللَّهِ ‏"‏ ‏.‏ ثُمَّ قَامَ فَخَطَبَ فَقَالَ ‏"‏ إِنَّمَا هَلَكَ الَّذِينَ قَبْلَكُمْ أَنَّهُمْ كَانُوا إِذَا سَرَقَ فِيهِمُ الشَّرِيفُ تَرَكُوهُ وَإِذَا سَرَقَ فِيهِمُ الضَّعِيفُ أَقَامُوا عَلَيْهِ الْحَدَّ وَايْمُ اللَّهِ لَوْ أَنَّ فَاطِمَةَ بِنْتَ مُحَمَّدٍ سَرَقَتْ لَقَطَعْتُ يَدَهَا ‏"‏ ‏.‏\hadithno{4899}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Aishah that Quraish were worried about the Mkahzumi woman who had stolen. They said; Who will speak to the Messenger of Allah concerning her?" They said:"Who would dare to do that except Usamah bin Zaid, the beloved of the Messenger of Allah?" so Usamah spoke to him and the Messenger of Allah said: "Are you interceding concerning one of the Hadd punishments decreed by Allah?" Then he stood up and addressed (the people) and said: "Those who came before you were destroyed because, whenever a noble person among them stole, they would let him go. But if a person who was weak stole, they would carry out the punishment on him. By Allah, if Fatimah the daughter of Muhammad were to steal, I would cut off her hnad}}
\hadithdefcmd{nasai}{4900}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ إِسْحَاقَ، قَالَ حَدَّثَنَا أَبُو الْجَوَّابِ، قَالَ حَدَّثَنَا عَمَّارُ بْنُ رُزَيْقٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، عَنْ مُحَمَّدِ بْنِ مُسْلِمٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ سَرَقَتِ امْرَأَةٌ مِنْ قُرَيْشٍ مِنْ بَنِي مَخْزُومٍ فَأُتِيَ بِهَا النَّبِيُّ صلى الله عليه وسلم فَقَالُوا مَنْ يُكَلِّمُهُ فِيهَا قَالُوا أُسَامَةُ بْنُ زَيْدٍ ‏.‏ فَأَتَاهُ فَكَلَّمَهُ فَزَبَرَهُ وَقَالَ ‏ "‏ إِنَّ بَنِي إِسْرَائِيلَ كَانُوا إِذَا سَرَقَ فِيهِمُ الشَّرِيفُ تَرَكُوهُ وَإِذَا سَرَقَ الْوَضِيعُ قَطَعُوهُ وَالَّذِي نَفْسِي بِيَدِهِ لَوْ أَنَّ فَاطِمَةَ بِنْتَ مُحَمَّدٍ سَرَقَتْ لَقَطَعْتُهَا ‏"‏ ‏.‏\hadithno{4900}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"A woman of Quraish, from banu Makhzum, stole, and she was brought to the Prophet. They said: 'Who will speak to him concerning her?' They said: 'Usamah bin Zaid.' So he came to the Prophet and spoke to him. But he rebuked him, and he said; 'Among the Children of Israel, if a noble person stole, they would let him go. But if a low-class person stole, they would cut off his hand. By the One in whose hand is the soul of Muhammad, if Fatimah bint Muhammad were to steal, I would cut off her hand}}
\hadithdefcmd{nasai}{4901}{أَخْبَرَنَا مُحَمَّدُ بْنُ جَبَلَةَ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ مُوسَى بْنِ أَعْيَنَ، قَالَ حَدَّثَنَا أَبِي، عَنْ إِسْحَاقَ بْنِ رَاشِدٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ قُرَيْشًا، أَهَمَّهُمْ شَأْنُ الْمَخْزُومِيَّةِ الَّتِي سَرَقَتْ فَقَالُوا مَنْ يُكَلِّمُ فِيهَا قَالُوا مَنْ يَجْتَرِئُ عَلَيْهِ إِلاَّ أُسَامَةُ بْنُ زَيْدٍ حِبُّ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَكَلَّمَهُ أُسَامَةُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا هَلَكَ الَّذِينَ مِنْ قَبْلِكُمْ أَنَّهُمْ كَانُوا إِذَا سَرَقَ فِيهِمُ الشَّرِيفُ تَرَكُوهُ وَإِذَا سَرَقَ فِيهِمُ الضَّعِيفُ أَقَامُوا عَلَيْهِ الْحَدَّ وَايْمُ اللَّهِ لَوْ سَرَقَتْ فَاطِمَةُ بِنْتُ مُحَمَّدٍ لَقَطَعْتُ يَدَهَا ‏"‏ ‏.‏\hadithno{4901}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah the Quraish were worried about the case of the Makhzumi woman who stole, and they said:"Who will speak concerning her?" They said: "Who would dare to do that except Usamah bin Zaid, the beloved of the Messenger of Allah?" said: "Those who came before you were destroyed because whenever a noble person among them stole they would let him go. But if a person who was weak stole, they would carry out the Hadd punishment. By Allah, if Fatimah, the daughter of Muhammad, were to steal, I would ct off her hand}}
\hadithdefcmd{nasai}{4902}{قَالَ الْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَنَّ عُرْوَةَ بْنَ الزُّبَيْرِ، أَخْبَرَهُ عَنْ عَائِشَةَ، أَنَّ امْرَأَةً، سَرَقَتْ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةِ الْفَتْحِ فَأُتِيَ بِهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَكَلَّمَهُ فِيهَا أُسَامَةُ بْنُ زَيْدٍ فَلَمَّا كَلَّمَهُ تَلَوَّنَ وَجْهُ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَتَشْفَعُ فِي حَدٍّ مِنْ حُدُودِ اللَّهِ ‏"‏ ‏.‏ فَقَالَ لَهُ أُسَامَةُ اسْتَغْفِرْ لِي يَا رَسُولَ اللَّهِ ‏.‏ فَلَمَّا كَانَ الْعَشِيُّ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَثْنَى عَلَى اللَّهِ عَزَّ وَجَلَّ بِمَا هُوَ أَهْلُهُ ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ إِنَّمَا هَلَكَ النَّاسُ قَبْلَكُمْ أَنَّهُمْ كَانُوا إِذَا سَرَقَ فِيهِمُ الشَّرِيفُ تَرَكُوهُ وَإِذَا سَرَقَ فِيهِمُ الضَّعِيفُ أَقَامُوا عَلَيْهِ الْحَدَّ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ لَوْ أَنَّ فَاطِمَةَ بِنْتَ مُحَمَّدٍ سَرَقَتْ قَطَعْتُ يَدَهَا ‏"‏ ‏.‏\hadithno{4902}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Aishah that:a woman stole at the time of the Messenger of Allah, during the Conquest, and she was brought to the Messenger of Allah. Usamah bin Zaid spoke to him concerning her. But when he spoke to him, the face of the Messenger of Allah changed color, and the Messenger of Allah said: "Are you interceding concerning one of the Hadd punishment decreed by Allah?" Isa,aj said to him: "O Messenger of Allah ask Allah to forgive me!" When evening came, the Messenger of Allah stood up and praised and glorified Allah, the mighty and sublime, as He deserves, then he said: "The people who came before you were destroyed because whenever a noble person among them stole, they would let him go. But if one who was weak stole, they would carry out the Hadd punishment on him." Then he said: "By the One in whose hand is my soul, if Fatimah bint Muhammad were to steal, I would cut off her hand}}
\hadithdefcmd{nasai}{4903}{أَخْبَرَنَا سُوَيْدٌ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ امْرَأَةً، سَرَقَتْ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةِ الْفَتْحِ - مُرْسَلٌ - فَفَزِعَ قَوْمُهَا إِلَى أُسَامَةَ بْنِ زَيْدٍ يَسْتَشْفِعُونَهُ - قَالَ عُرْوَةُ - فَلَمَّا كَلَّمَهُ أُسَامَةُ فِيهَا تَلَوَّنَ وَجْهُ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ أَتُكَلِّمُنِي فِي حَدٍّ مِنْ حُدُودِ اللَّهِ ‏"‏ ‏.‏ قَالَ أُسَامَةُ اسْتَغْفِرْ لِي يَا رَسُولَ اللَّهِ ‏.‏ فَلَمَّا كَانَ الْعَشِيُّ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَطِيبًا فَأَثْنَى عَلَى اللَّهِ بِمَا هُوَ أَهْلُهُ ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ فَإِنَّمَا هَلَكَ النَّاسُ قَبْلَكُمْ أَنَّهُمْ كَانُوا إِذَا سَرَقَ فِيهِمُ الشَّرِيفُ تَرَكُوهُ وَإِذَا سَرَقَ فِيهِمُ الضَّعِيفُ أَقَامُوا عَلَيْهِ الْحَدَّ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لَوْ أَنَّ فَاطِمَةَ بِنْتَ مُحَمَّدٍ سَرَقَتْ لَقَطَعْتُ يَدَهَا ‏"‏ ‏.‏ ثُمَّ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدِ تِلْكَ الْمَرْأَةِ فَقُطِعَتْ فَحَسُنَتْ تَوْبَتُهَا بَعْدَ ذَلِكَ ‏.‏ قَالَتْ عَائِشَةُ رضى الله عنها وَكَانَتْ تَأْتِينِي بَعْدَ ذَلِكَ فَأَرْفَعُ حَاجَتَهَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{4903}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Az-Zuhri said:"Urwah bin Az-Zubair told me that a woman stole at the time of the Messenger of Allah, during the Conquest. Her people went to Uswamah bin Zaid, to ask him to intercede." 'Urwah said: "When Usamah spoke to him concerning her, the face of the Messenger of Allah changed color and he said: 'Are you speaking to me concerning one of the Hadd punishments of Allah?" Usamah said: 'Pray to Allah for forgiveness for me, O Messenger of Allah.' When evening came, the Messenger of Allah stood up to deliver a speech. He praised Allah as He deserves, then he said: 'The people who came before you were destroyed because, whenever a noble person among them stole, they would carry out the Hadd punishment on him. By the One in whose hand is my soul, if Fatimah bint Muhammad were to steal, I would cut off her hand.' Then the Messenger of Allah ordered that the hand of that woman be cut off. After that she repented sincerely, and 'Aishah said: 'She used to come to me after that, and I would convey her needs to the Messenger of Allah}}
\hadithdefcmd{nasai}{4904}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ عِيسَى بْنِ يَزِيدَ، قَالَ حَدَّثَنِي جَرِيرُ بْنُ يَزِيدَ، أَنَّهُ سَمِعَ أَبَا زُرْعَةَ بْنَ عَمْرِو بْنِ جَرِيرٍ، يُحَدِّثُ أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ حَدٌّ يُعْمَلُ فِي الأَرْضِ خَيْرٌ لأَهْلِ الأَرْضِ مِنْ أَنْ يُمْطَرُوا ثَلاَثِينَ صَبَاحًا ‏"‏ ‏.‏\hadithno{4904}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah said:"The Messenger of Allah said: 'A Hadd punishment that is carried out on earth is better for the people of earth than if it were to rain for thirty mornings."' (Daif)}}
\hadithdefcmd{nasai}{4905}{أَخْبَرَنَا عَمْرُو بْنُ زُرَارَةَ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا يُونُسُ بْنُ عُبَيْدٍ، عَنْ جَرِيرِ بْنِ يَزِيدَ، عَنْ أَبِي زُرْعَةَ، قَالَ قَالَ أَبُو هُرَيْرَةَ إِقَامَةُ حَدٍّ بِأَرْضٍ خَيْرٌ لأَهْلِهَا مِنْ مَطَرِ أَرْبَعِينَ لَيْلَةً ‏.‏\hadithno{4905}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Zurah said:"Abu Hurairah said: 'Carrying out a Hadd punishment in a land is better for its people than if it were to rain for forty nights." (Daif)}}
\hadithdefcmd{nasai}{4906}{أَخْبَرَنَا عَبْدُ الْحَمِيدِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا مَخْلَدٌ، قَالَ حَدَّثَنَا حَنْظَلَةُ، قَالَ سَمِعْتُ نَافِعًا، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ، يَقُولُ قَطَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي مِجَنٍّ قِيمَتُهُ خَمْسَةُ دَرَاهِمَ ‏.‏ كَذَا قَالَ ‏.‏\hadithno{4906}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abdullah bin 'Amr said:"The Messenger of Allah cut off (a thief's hand) for a shield which was worth five Durham's." This is how he (the narrator) said it. (Daif)}}
\hadithdefcmd{nasai}{4907}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ حَدَّثَنَا حَنْظَلَةُ، أَنَّ نَافِعًا، حَدَّثَهُمْ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ قَالَ قَطَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي مِجَنٍّ ثَمَنُهُ ثَلاَثَةُ دَرَاهِمَ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا الصَّوَابُ ‏.‏\hadithno{4907}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdullah bin 'Umar said:"The Messenger of Allah cut off (a thief's hand) for a shield which was worth three Dirham." (Sahih) Abu 'Abdur-Rahman (An-Nasai) said: This is correct}}
\hadithdefcmd{nasai}{4908}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَطَعَ فِي مِجَنٍّ ثَمَنُهُ ثَلاَثَةُ دَرَاهِمَ ‏.‏\hadithno{4908}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that:the Messenger of Allah cut off (a thief's hand) for a shield which cost three Dirhams}}
\hadithdefcmd{nasai}{4909}{أَخْبَرَنَا يُوسُفُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ حَدَّثَنِي إِسْمَاعِيلُ بْنُ أُمَيَّةَ، أَنَّ نَافِعًا، حَدَّثَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ حَدَّثَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَطَعَ يَدَ سَارِقٍ سَرَقَ تُرْسًا مِنْ صُفَّةِ النِّسَاءِ ثَمَنُهُ ثَلاَثَةُ دَرَاهِمَ ‏.‏\hadithno{4909}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdullah bin 'Umar narrated that:the Prophet cut off the hand of a thief, who stole a shield, from a portico allocated to women, the price of which was three Dirhams}}
\hadithdefcmd{nasai}{4910}{أَخْبَرَنِي مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا أَبُو نُعَيْمٍ، عَنْ سُفْيَانَ، عَنْ أَيُّوبَ، وَإِسْمَاعِيلَ بْنِ أُمَيَّةَ، وَعُبَيْدِ اللَّهِ، وَمُوسَى بْنِ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَطَعَ فِي مِجَنٍّ قِيمَتُهُ ثَلاَثَةُ دَرَاهِمَ ‏.‏\hadithno{4910}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn 'Umar that:the Messenger of Allah cut off (a thief's hand) for a shield that was worth three Dirhams}}
\hadithdefcmd{nasai}{4911}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الصَّبَّاحِ، قَالَ حَدَّثَنَا أَبُو عَلِيٍّ الْحَنَفِيُّ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَطَعَ فِي مِجَنٍّ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا خَطَأٌ ‏.‏\hadithno{4911}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas bin Malik that:the Messenger of Allah cut off (a thief's hand) for a shield. (Sahih) Abu 'Abdur-Rahman (An-Nasai) said: This is a mistake}}
\hadithdefcmd{nasai}{4912}{أَخْبَرَنَا أَحْمَدُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْوَلِيدِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ قَطَعَ أَبُو بَكْرٍ رضى الله عنه فِي مِجَنٍّ قِيمَتُهُ خَمْسَةُ دَرَاهِمَ ‏.‏ هَذَا الصَّوَابُ ‏.‏\hadithno{4912}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas said:"Abu Bakr, may Allah be pleased with him, cut off (a thief's hand) for a shield that was worth five Dirhams}}
\hadithdefcmd{nasai}{4913}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ أَبِي دَاوُدَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَنَسًا، يَقُولُ سَرَقَ رَجُلٌ مِجَنًّا عَلَى عَهْدِ أَبِي بَكْرٍ فَقُوِّمَ خَمْسَةَ دَرَاهِمَ فَقُطِعَ ‏.‏\hadithno{4913}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Qatadah said:"I heard Anas say: 'A man stole a shield during the time of Abu Bakr, the value of which was five Dirhams, and he cut off his hand}}
\hadithdefcmd{nasai}{4914}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، عَنْ حَفْصِ بْنِ حَسَّانَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، رَضِيَ اللَّهُ عَنْهَا قَطَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي رُبُعِ دِينَارٍ ‏.‏\hadithno{4914}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah, may Allah be pleased with her, that:the Messenger of Allah cut off (a thief's hand) for one quarter of a Dinar}}
\hadithdefcmd{nasai}{4915}{أَنْبَأَنَا هَارُونُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنِي خَالِدُ بْنُ نِزَارٍ، قَالَ حَدَّثَنَا الْقَاسِمُ بْنُ مَبْرُورٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عُرْوَةُ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُقْطَعُ الْيَدُ إِلاَّ فِي ثَمَنِ الْمِجَنِّ ثُلُثِ دِينَارٍ أَوْ نِصْفِ دِينَارٍ فَصَاعِدًا ‏"‏ ‏.‏\hadithno{4915}\hadithgrade{Abu Ghuddah: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Aishah that the Messenger of Allah said:"(The thief's hand) is not to be cut off except for the price of a shield, one-third of a Dinar or half of Dinar, or more}}
\hadithdefcmd{nasai}{4916}{أَخْبَرَنَا مُحَمَّدُ بْنُ حَاتِمٍ، قَالَ أَنْبَأَنَا حِبَّانُ بْنُ مُوسَى، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، قَالَ قَالَتْ عَمْرَةُ عَنْ عَائِشَةَ، رضى الله عنها عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏ "‏ تُقْطَعُ يَدُ السَّارِقِ فِي رُبُعِ دِينَارٍ ‏"‏ ‏.‏\hadithno{4916}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Az-Zuhri said:"Amrah said, narrating from 'Aishah, may Allah be pleased with her, that the Messenger of Allah cut off the hand of a thief for a quarter of a Dinar}}
\hadithdefcmd{nasai}{4917}{قَالَ الْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، وَعَمْرَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ تُقْطَعُ يَدُ السَّارِقِ فِي رُبُعِ دِينَارٍ فَصَاعِدًا ‏"‏ ‏.‏\hadithno{4917}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Aishah that the Messenger of Allah said:"The hand of the thief is to be cut off for a quarter of a Dinar, or more}}
\hadithdefcmd{nasai}{4918}{أَخْبَرَنَا الْحَسَنُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَهَّابِ، عَنْ سَعِيدٍ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ تُقْطَعُ يَدُ السَّارِقِ فِي رُبُعِ دِينَارٍ فَصَاعِدًا ‏"‏ ‏.‏\hadithno{4918}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Aishah that the Prophet said:"The hand of the thief is to be cut off for one-quarter of a Dinar or more}}
\hadithdefcmd{nasai}{4919}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ تُقْطَعُ يَدُ السَّارِقِ فِي رُبُعِ دِينَارٍ فَصَاعِدًا ‏"‏ ‏.‏\hadithno{4919}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Aishah that the Messenger of Allah said:"The hand of the thief is to be cut off for one-quarter of a Dinar or more}}
\hadithdefcmd{nasai}{4920}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ مَعْمَرٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ تُقْطَعُ الْيَدُ فِي رُبُعِ دِينَارٍ فَصَاعِدًا ‏.‏\hadithno{4920}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Aishah that the Messenger of Allah said:"The hand of the thief is to be cut off for one-quarter of a Dinar or more}}
\hadithdefcmd{nasai}{4921}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ سُفْيَانَ، عَنِ الزُّهْرِيِّ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم - قَالَ قُتَيْبَةُ كَانَ النَّبِيُّ صلى الله عليه وسلم - يَقْطَعُ فِي رُبُعِ دِينَارٍ فَصَاعِدًا ‏.‏\hadithno{4921}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Aishah that the Messenger of Allah" (one of the narrators) Qutaibah said:'Used to cut off the hand of the thief for one-quarter of a Dinar or more}}
\hadithdefcmd{nasai}{4922}{أَخْبَرَنَا الْحَسَنُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَهَّابِ، عَنْ سَعِيدٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ تُقْطَعُ يَدُ السَّارِقِ فِي رُبُعِ دِينَارٍ فَصَاعِدًا ‏"‏ ‏.‏\hadithno{4922}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah, from the Prophet:"The hand of the thief is to be cut off for one-quarter of a Dinar or more}}
\hadithdefcmd{nasai}{4923}{أَخْبَرَنِي يَزِيدُ بْنُ مُحَمَّدِ بْنِ فُضَيْلٍ، قَالَ أَنْبَأَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا أَبَانُ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ تُقْطَعُ يَدُ السَّارِقِ فِي رُبُعِ دِينَارٍ فَصَاعِدًا ‏"‏ ‏.‏\hadithno{4923}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Aishah, from the Prophet:"The hand of the thief is to be cut off for one-quarter of a Dinar or more}}
\hadithdefcmd{nasai}{4924}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ، أَنَّهَا سَمِعَتْ عَائِشَةَ، تَقُولُ يُقْطَعُ فِي رُبُعِ دِينَارٍ فَصَاعِدًا ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا الصَّوَابُ مِنْ حَدِيثِ يَحْيَى ‏.‏\hadithno{4924}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Amrah that she heard 'Aishah say:"The hand of the thief is to be cut off for one-quarter of a Dinar or more." (Sahih) Abu 'Abdur-Rahman (An-Nasai) said: This is the correct version of the narration of Yahya}}
\hadithdefcmd{nasai}{4925}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا ابْنُ إِدْرِيسَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتِ الْقَطْعُ فِي رُبُعِ دِينَارٍ فَصَاعِدًا ‏.‏\hadithno{4925}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Amrah that she heard 'Aishah say:"The hand of the thief is to be cut off for one-quarter of a Dinar or more}}
\hadithdefcmd{nasai}{4926}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، وَعَبْدِ، رَبِّهِ وَرُزَيْقٍ صَاحِبِ أَيْلَةَ أَنَّهُمْ سَمِعُوا عَمْرَةَ عَنْ عَائِشَةَ قَالَتِ الْقَطْعُ فِي رُبُعِ دِينَارٍ فَصَاعِدًا ‏.‏\hadithno{4926}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Amrah that 'Aishah said:"Cutting off (the hand of the thief) is for one-quarter of a Dinar or more}}
\hadithdefcmd{nasai}{4927}{قَالَ الْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ مَا طَالَ عَلَىَّ وَلاَ نَسِيتُ الْقَطْعُ فِي رُبُعِ دِينَارٍ فَصَاعِدًا ‏.‏\hadithno{4927}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Aishah said:"It has not been too long and I have not forgotten yet. Cutting off (the hand of the thief) is for one-quarter of a Dinar or more}}
\hadithdefcmd{nasai}{4928}{أَخْبَرَنَا أَبُو صَالِحٍ، مُحَمَّدُ بْنُ زُنْبُورٍ قَالَ حَدَّثَنَا ابْنُ أَبِي حَازِمٍ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي بَكْرِ بْنِ مُحَمَّدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، أَنَّهَا سَمِعَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يُقْطَعُ السَّارِقُ إِلاَّ فِي رُبُعِ دِينَارٍ فَصَاعِدًا ‏"‏ ‏.‏\hadithno{4928}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Aishah that:she heard the Messenger of Allah say: "The hand of the thief is not be cut off except for one-quarter of a Dinar or more}}
\hadithdefcmd{nasai}{4929}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ سَلْمَانَ، ‏\{‏ عَنِ ابْنِ الْهَادِ، ‏\}‏ عَنْ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ حَزْمٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم مِثْلَ الأَوَّلِ ‏.‏\hadithno{4929}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrator mentioned in hadith:A similar report was narrated from 'Aishah from the Messenger of Allah}}
\hadithdefcmd{nasai}{4930}{قَالَ الْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ أَبِي بَكْرٍ، عَنْ عَمْرَةَ، قَالَتْ قَالَتْ عَائِشَةُ الْقَطْعُ فِي رُبُعِ دِينَارٍ فَصَاعِدًا ‏.‏\hadithno{4930}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Amrah said:"Aishah said: 'Cutting off (the hand of the thief) is for one-quarter of a Dinar or more}}
\hadithdefcmd{nasai}{4931}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي الرِّجَالِ، عَنْ أَبِيهِ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُقْطَعُ يَدُ السَّارِقِ فِي ثَمَنِ الْمِجَنِّ وَثَمَنُ الْمِجَنِّ رُبُعُ دِينَارٍ ‏"‏ ‏.‏\hadithno{4931}\hadithgrade{Abu Ghuddah: Hasan Sahih Isnaad; Al-Albani: Hasan Sahih Isnaad; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah said: 'The hand of the thief is to be cut off for the price of a shield, and the price of a shield is one-quarter of a Dinar}}
\hadithdefcmd{nasai}{4932}{أَخْبَرَنِي يَحْيَى بْنُ دُرُسْتَ، قَالَ حَدَّثَنَا أَبُو إِسْمَاعِيلَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، أَنَّ مُحَمَّدَ بْنَ عَبْدِ الرَّحْمَنِ، حَدَّثَهُ عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْطَعُ الْيَدَ فِي رُبُعِ دِينَارٍ فَصَاعِدًا ‏.‏\hadithno{4932}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah used to cut off the (thief's) hand for one-quarter of a Dinar or more}}
\hadithdefcmd{nasai}{4933}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، قَالَ حَدَّثَنَا حُسَيْنٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، ثُمَّ ذَكَرَ كَلِمَةً مَعْنَاهَا عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُقْطَعُ الْيَدُ إِلاَّ فِي رُبُعِ دِينَارٍ ‏"‏ ‏.‏\hadithno{4933}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah said: 'The hand (of the thief) is not to be cut off except for one-quarter of a Dinar}}
\hadithdefcmd{nasai}{4934}{أَخْبَرَنَا أَبُو بَكْرٍ، مُحَمَّدُ بْنُ إِسْمَاعِيلَ الطَّبَرَانِيُّ قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ بَحْرٍ أَبُو عَلِيٍّ، قَالَ حَدَّثَنَا مُبَارَكُ بْنُ سَعِيدٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي عِكْرِمَةُ، أَنَّ امْرَأَةً، أَخْبَرَتْهُ أَنَّ عَائِشَةَ أُمَّ الْمُؤْمِنِينَ أَخْبَرَتْهَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ تُقْطَعُ الْيَدُ فِي الْمِجَنِّ ‏"‏ ‏.‏\hadithno{4934}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Aishah, the mother of the believers, narrated that the Messenger of Allah said:"The hand (of the thief) is not to be cut off for a shield}}
\hadithdefcmd{nasai}{4935}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ سَعْدِ بْنِ إِبْرَاهِيمَ بْنِ سَعْدٍ، قَالَ حَدَّثَنَا عَمِّي، قَالَ حَدَّثَنَا أَبِي، عَنِ ابْنِ إِسْحَاقَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، أَنَّ بُكَيْرَ بْنَ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، حَدَّثَهُ أَنَّ سُلَيْمَانَ بْنَ يَسَارٍ حَدَّثَهُ أَنَّ عَمْرَةَ ابْنَةَ عَبْدِ الرَّحْمَنِ حَدَّثَتْهُ أَنَّهَا، سَمِعَتْ عَائِشَةَ، تَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُقْطَعُ يَدُ السَّارِقِ فِيمَا دُونَ الْمِجَنِّ ‏"‏ ‏.‏ قِيلَ لِعَائِشَةَ مَا ثَمَنُ الْمِجَنِّ قَالَتْ رُبُعُ دِينَارٍ ‏.‏\hadithno{4935}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Aishah said:The Messenger of Allah said: 'The hand of the thief is not to be cut off for anything less than a shield."' It was said to 'Aishah: 'What is the price of a shield?" She said: "One-quarter of a Dinar}}
\hadithdefcmd{nasai}{4936}{أَخْبَرَنِي أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي مَخْرَمَةُ، عَنْ أَبِيهِ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، أَنَّهَا سَمِعَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تُقْطَعُ يَدُ السَّارِقِ إِلاَّ فِي رُبُعِ دِينَارٍ فَصَاعِدًا ‏"‏ ‏.‏\hadithno{4936}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Aishah that she heard the Messenger of Allah say:"The hand of a thief is not to be cut off except for one-quarter of a Dinar or more}}
\hadithdefcmd{nasai}{4937}{أَخْبَرَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا قُدَامَةُ بْنُ مُحَمَّدٍ، قَالَ أَنْبَأَنَا مَخْرَمَةُ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ عُثْمَانَ بْنَ أَبِي الْوَلِيدِ، مَوْلَى الأَخْنَسِيِّينَ يَقُولُ سَمِعْتُ عُرْوَةَ بْنَ الزُّبَيْرِ، يَقُولُ كَانَتْ عَائِشَةُ تُحَدِّثُ عَنِ النَّبِيِّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تُقْطَعُ الْيَدُ إِلاَّ فِي الْمِجَنِّ أَوْ ثَمَنِهِ ‏"‏ ‏.‏\hadithno{4937}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Makhramah narrated that his father said:"I heard 'Uthman bin Abi AL-Walid, the freed slave of the Akhnasiyin, say: 'I heard 'Urwah bin Az-Zubair say;'Aishah used to narrated that the Prophet said: "The hand (of the htief) should notbe cut off for anything but a shield or its equivalent in value}}
\hadithdefcmd{nasai}{4938}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ إِسْحَاقَ، قَالَ حَدَّثَنِي قُدَامَةُ بْنُ مُحَمَّدٍ، قَالَ أَخْبَرَنِي مَخْرَمَةُ بْنُ بُكَيْرٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ عُثْمَانَ بْنَ أَبِي الْوَلِيدِ، يَقُولُ سَمِعْتُ عُرْوَةَ بْنَ الزُّبَيْرِ، يَقُولُ كَانَتْ عَائِشَةُ تُحَدِّثُ عَنْ نَبِيِّ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ لاَ تُقْطَعُ الْيَدُ إِلاَّ فِي الْمِجَنِّ أَوْ ثَمَنِهِ ‏"‏ ‏.‏ وَزَعَمَ أَنَّ عُرْوَةَ قَالَ الْمِجَنُّ أَرْبَعَةُ دَرَاهِمَ ‏.‏. قَالَ وَسَمِعْتُ سُلَيْمَانَ بْنَ يَسَارٍ، يَزْعُمُ أَنَّهُ سَمِعَ عَمْرَةَ، تَقُولُ سَمِعْتُ عَائِشَةَ، تُحَدِّثُ أَنَّهَا سَمِعَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ تُقْطَعُ الْيَدُ إِلاَّ فِي رُبُعِ دِينَارٍ فَمَا فَوْقَهُ ‏"‏ ‏.‏\hadithno{4938}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Uthman bin Abi Al-Walid said:"I heard 'Urwah bin Az-Zubair say: "Aishah used to narrate that he Prophet of Allah said: The hand (of the thief) should not be cut off except for a shield or its equivalent in value. And he said that 'Urwah said: A shield is (worth) four Dirhams. And he (the narrator) said: I heard sulaiman bin Yasar say that he heard 'Amrah say: I heard 'Aishah narrate that she heard the Messenger of Allah say: The hand (of the thief) should not be cut off except for four Dinars or more}}
\hadithdefcmd{nasai}{4939}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ إِسْحَاقَ، قَالَ حَدَّثَنِي قُدَامَةُ بْنُ مُحَمَّدٍ، قَالَ أَخْبَرَنِي مَخْرَمَةُ بْنُ بُكَيْرٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ عُثْمَانَ بْنَ أَبِي الْوَلِيدِ، يَقُولُ سَمِعْتُ عُرْوَةَ بْنَ الزُّبَيْرِ، يَقُولُ كَانَتْ عَائِشَةُ تُحَدِّثُ عَنْ نَبِيِّ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ لاَ تُقْطَعُ الْيَدُ إِلاَّ فِي الْمِجَنِّ أَوْ ثَمَنِهِ ‏"‏ ‏.‏ وَزَعَمَ أَنَّ عُرْوَةَ قَالَ الْمِجَنُّ أَرْبَعَةُ دَرَاهِمَ ‏.‏. قَالَ وَسَمِعْتُ سُلَيْمَانَ بْنَ يَسَارٍ، يَزْعُمُ أَنَّهُ سَمِعَ عَمْرَةَ، تَقُولُ سَمِعْتُ عَائِشَةَ، تُحَدِّثُ أَنَّهَا سَمِعَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ تُقْطَعُ الْيَدُ إِلاَّ فِي رُبُعِ دِينَارٍ فَمَا فَوْقَهُ ‏"‏ ‏.‏\hadithno{4939}\hadithtrans{Uthman bin Abi Al-Walid said:"I heard 'Urwah bin Az-Zubair say: "Aishah used to narrate that he Prophet of Allah said: The hand (of the thief) should not be cut off except for a shield or its equivalent in value. And he said that 'Urwah said: A shield is (worth) four Dirhams. And he (the narrator) said: I heard sulaiman bin Yasar say that he heard 'Amrah say: I heard 'Aishah narrate that she heard the Messenger of Allah say: The hand (of the thief) should not be cut off except for four Dinars or more}}
\hadithdefcmd{nasai}{4940}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالَ حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ عَبْدِ اللَّهِ الدَّانَاجِ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، قَالَ لاَ تُقْطَعُ الْخَمْسُ إِلاَّ فِي الْخَمْسِ ‏.‏ قَالَ هَمَّامٌ فَلَقِيتُ عَبْدَ اللَّهِ الدَّانَاجَ فَحَدَّثَنِي عَنْ سُلَيْمَانَ بْنِ يَسَارٍ قَالَ لاَ تُقْطَعُ الْخَمْسُ إِلاَّ فِي الْخَمْسِ ‏.‏\hadithno{4940}\hadithgrade{Abu Ghuddah: Sahih Maqtu; Al-Albani: Sahih Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that sulaiman bin Yasar said:"Five (fingers i.e., the hand) should not be cut off except for five." Hammam said: "I met 'Abdullah Ad-Danaj and he narrated to me that Sulaiman bin Yasar said: "Five should not be cut off except for five." (Sahih Maqtu)}}
\hadithdefcmd{nasai}{4941}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ لَمْ تُقْطَعْ يَدُ سَارِقٍ فِي أَدْنَى مِنْ حَجَفَةٍ أَوْ تُرْسٍ وَكُلُّ وَاحِدٍ مِنْهُمَا ذُو ثَمَنٍ ‏.‏\hadithno{4941}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that 'Aishah said:"The hand of the thief should not be cut off for anything less than a Hajafah or a Turs (two kinds of shields)," each of which was worth a (decent) price}}
\hadithdefcmd{nasai}{4942}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ عِيسَى، عَنِ الشَّعْبِيِّ، عَنْ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَطَعَ فِي قِيمَةِ خَمْسَةِ دَرَاهِمَ ‏.‏\hadithno{4942}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Abdullah that:the Prophet cut off (the thief's hand) for (something) that was worth five Dirhams. (Daif)}}
\hadithdefcmd{nasai}{4943}{وَأَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا مُعَاوِيَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنْ عَطَاءٍ، عَنْ أَيْمَنَ، قَالَ لَمْ يَقْطَعِ النَّبِيُّ صلى الله عليه وسلم السَّارِقَ إِلاَّ فِي ثَمَنِ الْمِجَنِّ وَثَمَنُ الْمِجَنِّ يَوْمَئِذٍ دِينَارٌ ‏.‏\hadithno{4943}\hadithgrade{Abu Ghuddah: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ayman said:"The Prophet did not cut off the (hand of) the thief except for the value of a shield, and the value of a shield in those days was a Dinar." (Daif)}}
\hadithdefcmd{nasai}{4944}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنْ أَيْمَنَ، قَالَ لَمْ تَكُنْ تُقْطَعُ الْيَدُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلاَّ فِي ثَمَنِ الْمِجَنِّ وَقِيمَتُهُ يَوْمَئِذٍ دِينَارٌ ‏.‏\hadithno{4944}\hadithgrade{Abu Ghuddah: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ayman said:"The hand of a thief would not be cut off during the time of the Messenger of Allah except for the value of a shield, which in those days was a Dinar." (Daif)}}
\hadithdefcmd{nasai}{4945}{أَخْبَرَنَا أَبُو الأَزْهَرِ النَّيْسَابُورِيُّ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنِ الْحَكَمِ، عَنْ مُجَاهِدٍ، عَنْ أَيْمَنَ، قَالَ لَمْ تُقْطَعِ الْيَدُ فِي زَمَنِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلاَّ فِي ثَمَنِ الْمِجَنِّ وَقِيمَةُ الْمِجَنِّ يَوْمَئِذٍ دِينَارٌ ‏.‏\hadithno{4945}\hadithgrade{Abu Ghuddah: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ayman said:"The hand of a thief was not be cut off during the time of the Messenger of Allah except for the value of a shield, and the value of a shield in those days was a Dinar." (Daif)}}
\hadithdefcmd{nasai}{4946}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، عَنْ عَلِيِّ بْنِ صَالِحٍ، عَنْ مَنْصُورٍ، عَنِ الْحَكَمِ، عَنْ مُجَاهِدٍ، وَعَطَاءٍ، عَنْ أَيْمَنَ، قَالَ لَمْ تُقْطَعِ الْيَدُ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلاَّ فِي ثَمَنِ الْمِجَنِّ وَثَمَنُهُ يَوْمَئِذٍ دِينَارٌ ‏.‏\hadithno{4946}\hadithgrade{Abu Ghuddah: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ayman said:"The hand of a thief was not be cut off during the time of the Messenger of Allah except for the price of a shield, which in those days was a Dinar." (Daif)}}
\hadithdefcmd{nasai}{4947}{أَخْبَرَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا الأَسْوَدُ بْنُ عَامِرٍ، قَالَ أَنْبَأَنَا الْحَسَنُ بْنُ حَىٍّ، عَنْ مَنْصُورٍ، عَنِ الْحَكَمِ، عَنْ عَطَاءٍ، وَمُجَاهِدٍ، عَنْ أَيْمَنَ، قَالَ يُقْطَعُ السَّارِقُ فِي ثَمَنِ الْمِجَنِّ وَكَانَ ثَمَنُ الْمِجَنِّ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم دِينَارًا أَوْ عَشْرَةَ دَرَاهِمَ ‏.‏\hadithno{4947}\hadithgrade{Abu Ghuddah: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ayman said:"The (hand of) a thief is to be cut off for the price of a shield, and the price of a shield during the time of the Messenger of Allah was a Dinar, or ten Dirhams." (Daif)}}
\hadithdefcmd{nasai}{4948}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا شَرِيكٌ، عَنْ مَنْصُورٍ، عَنْ عَطَاءٍ، وَمُجَاهِدٍ، عَنْ أَيْمَنَ بْنِ أُمِّ أَيْمَنَ، يَرْفَعُهُ قَالَ ‏ "‏ لاَ تُقْطَعُ الْيَدُ إِلاَّ فِي ثَمَنِ الْمِجَنِّ ‏"‏ ‏.‏ وَثَمَنُهُ يَوْمَئِذٍ دِينَارٌ ‏.‏\hadithno{4948}\hadithgrade{Abu Ghuddah: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ayman bin Umm Ayman who attributed it to the Prophet said:"The (hand of) a thief is not to be cut off except for the price of a shield, and in those days the price of a shield was a Dinar}}
\hadithdefcmd{nasai}{4949}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ عَطَاءٍ، وَمُجَاهِدٍ، عَنْ أَيْمَنَ، قَالَ لاَ يُقْطَعُ السَّارِقُ فِي أَقَلَّ مِنْ ثَمَنِ الْمِجَنِّ ‏.‏\hadithno{4949}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ayman said:"The (hand of) a thief is not to be cut off for less than the price of a shield." (Daif Mawquf)}}
\hadithdefcmd{nasai}{4950}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعْدِ بْنِ إِبْرَاهِيمَ بْنِ سَعْدٍ، قَالَ حَدَّثَنَا عَمِّي، قَالَ حَدَّثَنَا أَبِي، عَنِ ابْنِ إِسْحَاقَ، قَالَ حَدَّثَنَا عَمْرُو بْنُ شُعَيْبٍ، أَنَّ عَطَاءَ بْنَ أَبِي رَبَاحٍ، حَدَّثَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ كَانَ يَقُولُ ثَمَنُهُ يَوْمَئِذٍ عَشْرَةُ دَرَاهِمَ ‏.‏\hadithno{4950}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Daif}\hadithtrans{Ata, bin Abi Rabah narrated that 'Abdullah bin 'Abbas used to say:"Its price in those days was ten Dirhams}}
\hadithdefcmd{nasai}{4951}{أَخْبَرَنَا يَحْيَى بْنُ مُوسَى الْبَلْخِيُّ، قَالَ حَدَّثَنَا ابْنُ نُمَيْرٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ أَيُّوبَ بْنِ مُوسَى، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، مِثْلَهُ كَانَ ثَمَنُ الْمِجَنِّ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم يُقَوَّمُ عَشْرَةَ دَرَاهِمَ ‏.‏\hadithno{4951}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Abbas:A similar report was narrated from Ibn 'Abbas. The price of a shield at the time of the Messenger of Allah was estimated to be ten Dirhams}}
\hadithdefcmd{nasai}{4952}{أَخْبَرَنِي مُحَمَّدُ بْنُ وَهْبٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنِي ابْنُ إِسْحَاقَ، عَنْ أَيُّوبَ بْنِ مُوسَى، عَنْ عَطَاءٍ، مُرْسَلٌ ‏.‏\hadithno{4952}\hadithgrade{Abu Ghuddah: -; Zubair Ali Zai: Hasan}\hadithtrans{Narrated from Ayyub bin Musa:(A similar report) was narrated from Ayyub bin Musa, from 'Ata, in Mursal form}}
\hadithdefcmd{nasai}{4953}{أَخْبَرَنِي حُمَيْدُ بْنُ مَسْعَدَةَ، عَنْ سُفْيَانَ، - وَهُوَ ابْنُ حَبِيبٍ - عَنِ الْعَرْزَمِيِّ، - وَهُوَ عَبْدُ الْمَلِكِ بْنُ أَبِي سُلَيْمَانَ - عَنْ عَطَاءٍ، قَالَ أَدْنَى مَا يُقْطَعُ فِيهِ ثَمَنُ الْمِجَنِّ ‏.‏ قَالَ وَثَمَنُ الْمِجَنِّ يَوْمَئِذٍ عَشْرَةُ دَرَاهِمَ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ وَأَيْمَنُ الَّذِي تَقَدَّمَ ذِكْرُنَا لِحَدِيثِهِ مَا أَحْسَبُ أَنَّ لَهُ صُحْبَةً وَقَدْ رُوِيَ عَنْهُ حَدِيثٌ آخَرُ يَدُلُّ عَلَى مَا قُلْنَاهُ ‏.‏\hadithno{4953}\hadithgrade{Abu Ghuddah: Daif Maqtu; Al-Albani: Maqtu; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Ata' said:"The least for which the hand of a thief is to be cut off is the price of a shield. And the price of a shield in those days was ten Dirhams." (Hasan) Abu 'Abdur-Rahman (An-Nasai) said: Ayman, the one whose narrations preceded, I do not think he was a Companion, and another Hadith has been related from him which proves what we have said:}}
\hadithdefcmd{nasai}{4954}{حَدَّثَنَا سَوَّارُ بْنُ عَبْدِ اللَّهِ بْنِ سَوَّارٍ، قَالَ حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، قَالَ حَدَّثَنَا عَبْدُ الْمَلِكِ، ح وَأَنْبَأَنَا عَبْدُ الرَّحْمَنِ بْنُ مُحَمَّدِ بْنِ سَلاَّمٍ، قَالَ أَنْبَأَنَا إِسْحَاقُ، - هُوَ الأَزْرَقُ - قَالَ حَدَّثَنَا بِهِ عَبْدُ الْمَلِكِ، عَنْ عَطَاءٍ، عَنْ أَيْمَنَ، مَوْلَى ابْنِ الزُّبَيْرِ - وَقَالَ خَالِدٌ فِي حَدِيثِهِ مَوْلَى الزُّبَيْرِ - عَنْ تُبَيْعٍ عَنْ كَعْبٍ قَالَ مَنْ تَوَضَّأَ فَأَحْسَنَ الْوُضُوءَ ثُمَّ صَلَّى - وَقَالَ عَبْدُ الرَّحْمَنِ فَصَلَّى الْعِشَاءَ الآخِرَةَ - ثُمَّ صَلَّى بَعْدَهَا أَرْبَعَ رَكَعَاتٍ فَأَتَمَّ - وَقَالَ سَوَّارٌ يُتِمُّ - رُكُوعَهُنَّ وَسُجُودَهُنَّ وَيَعْلَمُ مَا يَقْتَرِئُ - وَقَالَ سَوَّارٌ يَقْرَأُ - فِيهِنَّ كُنَّ لَهُ بِمَنْزِلَةِ لَيْلَةِ الْقَدْرِ ‏.‏\hadithno{4954}\hadithgrade{Abu Ghuddah: Maqtu; Al-Albani: Maqtu}\hadithtrans{It was narrated that Ka'b said:"Whoever performs wudu and performs wudu, well, then prays ('Abdur-Rahman said: and prays Isha), then prays after that four Rakahs and does them well (Sawwar said: and understands what he is reciting (Sawwar said: and recites therein), they will be equivalent to (praying) Lailat Al-Qadr for him". (Hasan Maqtu)}}
\hadithdefcmd{nasai}{4955}{أَخْبَرَنَا عَبْدُ الْحَمِيدِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا مَخْلَدٌ، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ أَيْمَنَ، مَوْلَى ابْنِ عُمَرَ عَنْ تُبَيْعٍ، عَنْ كَعْبٍ، قَالَ مَنْ تَوَضَّأَ فَأَحْسَنَ وُضُوءَهُ ثُمَّ شَهِدَ صَلاَةَ الْعَتَمَةِ فِي جَمَاعَةٍ ثُمَّ صَلَّى إِلَيْهَا أَرْبَعًا مِثْلَهَا يَقْرَأُ فِيهَا وَيُتِمُّ رُكُوعَهَا وَسُجُودَهَا كَانَ لَهُ مِنَ الأَجْرِ مِثْلُ لَيْلَةِ الْقَدْرِ ‏.‏\hadithno{4955}\hadithgrade{Abu Ghuddah: Maqtu; Al-Albani: Maqtu; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ka'b said:"Whoever performs Wudu and performs Wudu well, then attends Isha prayer in congregation, then prays four similar Rakahs after that, reciting therein and bowing and prostrating perfectly, that will bring him a reward like that of (praying) Lailat Al-Qadar." (Hasan Maqtu)}}
\hadithdefcmd{nasai}{4956}{أَخْبَرَنَا خَلاَّدُ بْنُ أَسْلَمَ، عَنْ عَبْدِ اللَّهِ بْنِ إِدْرِيسَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ كَانَ ثَمَنُ الْمِجَنِّ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم عَشْرَةَ دَرَاهِمَ ‏.‏\hadithno{4956}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh}\hadithtrans{It was narrated from 'Amr bin Shuaib, from his father, that his grandfather said:"The price of a shield at the time of the Messenger of Allah was ten Dirhams}}
\hadithdefcmd{nasai}{4957}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ الأَخْنَسِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي كَمْ تُقْطَعُ الْيَدُ قَالَ ‏ "‏ لاَ تُقْطَعُ الْيَدُ فِي ثَمَرٍ مُعَلَّقٍ فَإِذَا ضَمَّهُ الْجَرِينُ قُطِعَتْ فِي ثَمَنِ الْمِجَنِّ وَلاَ تُقْطَعُ فِي حَرِيسَةِ الْجَبَلِ فَإِذَا آوَى الْمُرَاحَ قُطِعَتْ فِي ثَمَنِ الْمِجَنِّ ‏"‏ ‏.‏\hadithno{4957}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Amr bin Shuaib, from his father, that his grandfather said:"The Messenger of Allah was asked: 'For how much is the hand (of the thief) to be cut off?' He said: 'The hand (of the thief) is not to be cut off for (stealing) fruit on the tree, but if (the fruit) has been taken to the place where it is stored to dry, then the (thief's) hand is to be cut off (if what is stolen is equivalent to) the price of a shield. The (thief's) hand is not to be cut off for a sheep (stolen) from the grazing land, but if it had been put in the pen, then the (thief's) hand is to be cut off (if what is stolen is equivalent to) the price of a shield}}
\hadithdefcmd{nasai}{4958}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ سُئِلَ عَنِ الثَّمَرِ الْمُعَلَّقِ فَقَالَ ‏ "‏ مَا أَصَابَ مِنْ ذِي حَاجَةٍ غَيْرِ مُتَّخِذٍ خُبْنَةً فَلاَ شَىْءَ عَلَيْهِ وَمَنْ خَرَجَ بِشَىْءٍ مِنْهُ فَعَلَيْهِ غَرَامَةُ مِثْلَيْهِ وَالْعُقُوبَةُ وَمَنْ سَرَقَ شَيْئًا مِنْهُ بَعْدَ أَنْ يُئْوِيَهُ الْجَرِينُ فَبَلَغَ ثَمَنَ الْمِجَنِّ فَعَلَيْهِ الْقَطْعُ وَمَنْ سَرَقَ دُونَ ذَلِكَ فَعَلَيْهِ غَرَامَةُ مِثْلَيْهِ وَالْعُقُوبَةُ ‏"‏ ‏.‏\hadithno{4958}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Amr bin Shuaib, from his father, that his grandfather 'Abdullah bin 'Amr, that the Messenger of Allah wsa asked about fruit on the tree. He said:"Whatever a needy person takes without putting any in his pocket (and taking it away), there is no penalty on him. But whoever takes anything away, he must pay a penalty of twice its value, and be punished. Whoever steals something after it has been stored properly, and its value is equal to that of a shield, his hand must be cut off. Whoever steals something worth less than that, he must pay a penalty of twice its value and be punished}}
\hadithdefcmd{nasai}{4959}{قَالَ الْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، وَهِشَامُ بْنُ سَعْدٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ رَجُلاً، مِنْ مُزَيْنَةَ أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ كَيْفَ تَرَى فِي حَرِيسَةِ الْجَبَلِ فَقَالَ ‏"‏ هِيَ وَمِثْلُهَا وَالنَّكَالُ وَلَيْسَ فِي شَىْءٍ مِنَ الْمَاشِيَةِ قَطْعٌ إِلاَّ فِيمَا آوَاهُ الْمُرَاحُ فَبَلَغَ ثَمَنَ الْمِجَنِّ فَفِيهِ قَطْعُ الْيَدِ وَمَا لَمْ يَبْلُغْ ثَمَنَ الْمِجَنِّ فَفِيهِ غَرَامَةُ مِثْلَيْهِ وَجَلَدَاتُ نَكَالٍ ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ كَيْفَ تَرَى فِي الثَّمَرِ الْمُعَلَّقِ قَالَ ‏"‏ هُوَ وَمِثْلُهُ مَعَهُ وَالنَّكَالُ وَلَيْسَ فِي شَىْءٍ مِنَ الثَّمَرِ الْمُعَلَّقِ قَطْعٌ إِلاَّ فِيمَا آوَاهُ الْجَرِينُ فَمَا أُخِذَ مِنَ الْجَرِينِ فَبَلَغَ ثَمَنَ الْمِجَنِّ فَفِيهِ الْقَطْعُ وَمَا لَمْ يَبْلُغْ ثَمَنَ الْمِجَنِّ فَفِيهِ غَرَامَةُ مِثْلَيْهِ وَجَلَدَاتُ نَكَالٍ ‏"‏ ‏.‏\hadithno{4959}\hadithgrade{Abu Ghuddah: -; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Amr bin Shuaib, from his father, that his grandfather 'Abdullah bin 'Amr, that a man from Muzainah came to the Messenger of Allah and said:'O Messenger of Allah, what do you think about a sheep stolen from the pasture?" He said: "(The thief must pay) double and be punished. There is no cutting off of the hand for (stealing) livestock, except what which has been put in the pen, if its value is equal to that of a shield, in which case the (thief's) hand is to be cut off. If its value is not equal to that of a shield, then he should pay a penalty of twice its value and be flogged as a punishment." He said: "O Messenger of Allah! What do you think about fruit on the tree?" He said: "(The thief must pay) double and be punished. There is no cutting off of the hand for (stealing) fruit on the tree, except for that which has been stored properly if its value is equal to that of a shield, in which case the (thief's) hand is not equal to that of a shield, then he should pay a penalty of twice its value and be flogged as a punishment}}
\hadithdefcmd{nasai}{4960}{أَخْبَرَنَا مُحَمَّدُ بْنُ خَالِدِ بْنِ خَلِيٍّ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا سَلَمَةُ، - يَعْنِي ابْنَ عَبْدِ الْمَلِكِ الْعَوْصِيَّ - عَنِ الْحَسَنِ، - وَهُوَ ابْنُ صَالِحٍ - عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدِ بْنِ أَبِي بَكْرٍ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ قَطْعَ فِي ثَمَرٍ وَلاَ كَثَرٍ ‏"‏ ‏.‏\hadithno{4960}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Rafi bin Khadij said:"I heard the Messenger of Allah say: 'The hand is not to be cut off for (stealing) produce or the spadix of palm trees}}
\hadithdefcmd{nasai}{4961}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ سَمِعْتُ يَحْيَى بْنَ سَعِيدٍ الْقَطَّانَ، يَقُولُ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ قَطْعَ فِي ثَمَرٍ وَلاَ كَثَرٍ ‏"‏ ‏.‏\hadithno{4961}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Rafi bin Khadij said:"I heard the Messenger of Allah say: 'The hand is not to be cut off for (stealing) produce or the spadix of palm trees}}
\hadithdefcmd{nasai}{4962}{أَخْبَرَنِي يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ يَحْيَى، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ قَطْعَ فِي ثَمَرٍ وَلاَ كَثَرٍ ‏"‏ ‏.‏\hadithno{4962}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Rafi bin Khadij said:"I heard the Messenger of Allah say: 'The hand is not to be cut off for (stealing) produce or the spadix of palm trees}}
\hadithdefcmd{nasai}{4963}{أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ مُحَمَّدِ بْنِ سَلاَّمٍ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ قَطْعَ فِي ثَمَرٍ وَلاَ كَثَرٍ ‏"‏ ‏.‏\hadithno{4963}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Rafi bin Khadij said:"I heard the Messenger of Allah say: 'The hand is not to be cut off for (stealing) produce or the spadix of palm trees}}
\hadithdefcmd{nasai}{4964}{أَخْبَرَنَا عَبْدُ الْحَمِيدِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا مَخْلَدٌ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ يَحْيَى، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ رَافِعِ بْنِ خَدِيجٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ قَطْعَ فِي ثَمَرٍ وَلاَ كَثَرٍ ‏"‏ ‏.‏\hadithno{4964}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Rafi bin Khadij said:"I heard the Messenger of Allah say: 'The hand is not to be cut off for (stealing) produce or the spadix of palm trees}}
\hadithdefcmd{nasai}{4965}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا أَبُو نُعَيْمٍ، عَنْ سُفْيَانَ، عَنْ يَحْيَى، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ قَطْعَ فِي ثَمَرٍ وَلاَ كَثَرٍ ‏"‏ ‏.‏\hadithno{4965}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Rafi bin Khadij said:"I heard the Messenger of Allah say: 'The hand is not to be cut off for (stealing) produce or the spadix of palm trees}}
\hadithdefcmd{nasai}{4966}{أَخْبَرَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ عُبَيْدِ اللَّهِ، - هُوَ ابْنُ أَبِي رَجَاءٍ - قَالَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ عَمِّهِ، وَاسِعٍ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ قَطْعَ فِي ثَمَرٍ وَلاَ كَثَرٍ ‏"‏ ‏.‏\hadithno{4966}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Rafi bin Khadij said:"I heard the Messenger of Allah say: 'The hand is not to be cut off for (stealing) produce or the spadix of palm trees}}
\hadithdefcmd{nasai}{4967}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ عَمِّهِ، أَنَّ رَافِعَ بْنَ خَدِيجٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ قَطْعَ فِي ثَمَرٍ وَلاَ كَثَرٍ ‏"‏ ‏.‏ وَالْكَثَرُ الْجُمَّارُ ‏.‏\hadithno{4967}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Rafi bin Khadij said:"I heard the Messenger of Allah say: 'The hand is not be cut off for (stealing) produce or the spadix of palm trees}}
\hadithdefcmd{nasai}{4968}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَلِيِّ بْنِ مَيْمُونٍ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ أَبِي مَيْمُونٍ، عَنْ رَافِعِ بْنِ خَدِيجٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ قَطْعَ فِي ثَمَرٍ وَلاَ كَثَرٍ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا خَطَأٌ أَبُو مَيْمُونٍ لاَ أَعْرِفُهُ ‏.‏\hadithno{4968}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Rafi bin Khadij said:"I heard the Messenger of Allah say: 'The hand is not to be cut off for (stealing) produce or the spadix of palm trees."' (Sahih) Abu 'Abdur-Rahman (An-Nasai) said: This is a mistake, and I do not know who Abu Maimun (one of the narrators) is}}
\hadithdefcmd{nasai}{4969}{أَخْبَرَنَا الْحُسَيْنُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ رَجُلٍ، مِنْ قَوْمِهِ عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ قَطْعَ فِي ثَمَرٍ وَلاَ كَثَرٍ ‏"‏ ‏.‏\hadithno{4969}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Rafi bin Khadij said:"I heard the Messenger of Allah say: 'The hand is not to be cut off for (stealing) produce or the spadix of palm trees}}
\hadithdefcmd{nasai}{4970}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا بِشْرٌ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، أَنَّ رَجُلاً، مِنْ قَوْمِهِ حَدَّثَهُ عَنْ عَمٍّ، لَهُ أَنَّ رَافِعَ بْنَ خَدِيجٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ قَطْعَ فِي ثَمَرٍ وَلاَ كَثَرٍ ‏"‏ ‏.‏\hadithno{4970}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Rafi bin Khadij said:"I heard the Messenger of Allah say: 'The hand is not to be cut off for (stealing) produce or the spadix of palm trees}}
\hadithdefcmd{nasai}{4971}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الصَّمَدِ بْنِ عَلِيٍّ، عَنْ مَخْلَدٍ، عَنْ سُفْيَانَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ عَلَى خَائِنٍ وَلاَ مُنْتَهِبٍ وَلاَ مُخْتَلِسٍ قَطْعٌ ‏"‏ ‏.‏ لَمْ يَسْمَعْهُ سُفْيَانُ مِنْ أَبِي الزُّبَيْرِ ‏.‏\hadithno{4971}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Sufyan, from Abu Az-Zubair, from Jabir that:the Messenger of Allah robber and pilferer is not to be cut off." (Sahih) Sufyan did not hear it from Abu Az-Zubair}}
\hadithdefcmd{nasai}{4972}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ الْحَفَرِيُّ، عَنْ سُفْيَانَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ عَلَى خَائِنٍ وَلاَ مُنْتَهِبٍ وَلاَ مُخْتَلِسٍ قَطْعٌ ‏"‏ ‏.‏ وَلَمْ يَسْمَعْهُ أَيْضًا ابْنُ جُرَيْجٍ مِنْ أَبِي الزُّبَيْرِ ‏.‏\hadithno{4972}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Sufyan, from Abu Az-Zubair, that Jabir said:"The Messenger of Allah said: 'The pilferer is not to be cut off."' (Sahih) Ibn Juraij also did not hear it from Abu Az-Zubair. Ibn Juraij also did not hear it from Abu Az-Zubair}}
\hadithdefcmd{nasai}{4973}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ الْحَسَنِ، عَنْ حَجَّاجٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ قَالَ أَبُو الزُّبَيْرِ عَنْ جَابِرٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ عَلَى الْمُخْتَلِسِ قَطْعٌ ‏"‏ ‏.‏\hadithno{4973}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Jabir that the Messenger of Allah said:"The hand of the pilferer is not to be cut off}}
\hadithdefcmd{nasai}{4974}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ الْحَسَنِ، عَنْ حَجَّاجٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ قَالَ أَبُو الزُّبَيْرِ قَالَ جَابِرٌ لَيْسَ عَلَى الْخَائِنِ قَطْعٌ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ وَقَدْ رَوَى هَذَا الْحَدِيثَ عَنِ ابْنِ جُرَيْجٍ عِيسَى بْنُ يُونُسَ وَالْفَضْلُ بْنُ مُوسَى وَابْنُ وَهْبٍ وَمُحَمَّدُ بْنُ رَبِيعَةَ وَمَخْلَدُ بْنُ يَزِيدَ وَسَلَمَةُ بْنُ سَعِيدٍ - بَصْرِيٌّ ثِقَةٌ - قَالَ ابْنُ أَبِي صَفْوَانَ وَكَانَ خَيْرَ أَهْلِ زَمَانِهِ ‏.‏ فَلَمْ يَقُلْ أَحَدٌ مِنْهُمْ حَدَّثَنِي أَبُو الزُّبَيْرِ وَلاَ أَحْسَبُهُ سَمِعَهُ مِنْ أَبِي الزُّبَيْرِ وَاللَّهُ تَعَالَى أَعْلَمُ ‏.‏\hadithno{4974}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Hajjaj from Ibn Juraij from Abu Az-Zubair, that Jabir said:"The hands of the traitor is not to be cut off." (Sahih) Abu 'Abdur-Rahman (An-Nasai) said: This Hadith had been reported from Ibn Juraij by 'Isa bin Yunus, Al-Fadl bin Musa, Ibn Wahb, Muhammad bin Rabiah, Makhlad bin Yazid, and Salamah bin Saeed from Al-Basrah, who is trustworthy and Ibn Abi Safwan said: "He was the best of the people of his time" and not one of them said: "Abu Az-Zubair narrated to me" and I do not think that he heard it from Abu Az-Zubair, and Allah knows best}}
\hadithdefcmd{nasai}{4975}{أَخْبَرَنَا خَالِدُ بْنُ رَوْحٍ الدِّمَشْقِيُّ، قَالَ حَدَّثَنَا يَزِيدُ، - يَعْنِي ابْنَ خَالِدِ بْنِ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ مَوَهِبٍ - قَالَ حَدَّثَنَا شَبَابَةُ، عَنِ الْمُغِيرَةِ بْنِ مُسْلِمٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ عَلَى مُخْتَلِسٍ وَلاَ مُنْتَهِبٍ وَلاَ خَائِنٍ قَطْعٌ ‏"‏ ‏.‏\hadithno{4975}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah said: 'The hand of the pilferer, robber and traitor is not to be cut off}}
\hadithdefcmd{nasai}{4976}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا أَبُو خَالِدٍ، عَنْ أَشْعَثَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ لَيْسَ عَلَى خَائِنٍ قَطْعٌ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ أَشْعَثُ بْنُ سَوَّارٍ ضَعِيفٌ ‏.‏\hadithno{4976}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jabir said:"The hand of the traitor is not to be cut off." (Sahih) Abu 'Abdur-Rahman (An-Nasai) said: Ashath bin Sawwar (one of its narrators) is weak}}
\hadithdefcmd{nasai}{4977}{أَخْبَرَنَا سُلَيْمَانُ بْنُ سَلْمٍ الْمَصَاحِفِيُّ الْبَلْخِيُّ، قَالَ حَدَّثَنَا النَّضْرُ بْنُ شُمَيْلٍ، قَالَ حَدَّثَنَا حَمَّادٌ، قَالَ أَنْبَأَنَا يُوسُفُ، عَنِ الْحَارِثِ بْنِ حَاطِبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أُتِيَ بِلِصٍّ فَقَالَ ‏"‏ اقْتُلُوهُ ‏"‏ ‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ إِنَّمَا سَرَقَ ‏.‏ فَقَالَ ‏"‏ اقْتُلُوهُ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ إِنَّمَا سَرَقَ ‏.‏ قَالَ ‏"‏ اقْطَعُوا يَدَهُ ‏"‏ ‏.‏ قَالَ ثُمَّ سَرَقَ فَقُطِعَتْ رِجْلُهُ ثُمَّ سَرَقَ عَلَى عَهْدِ أَبِي بَكْرٍ رضى الله عنه حَتَّى قُطِعَتْ قَوَائِمُهُ كُلُّهَا ثُمَّ سَرَقَ أَيْضًا الْخَامِسَةَ فَقَالَ أَبُو بَكْرٍ رضى الله عنه كَانَ رَسُولُ اللَّهُ صلى الله عليه وسلم أَعْلَمَ بِهَذَا حِينَ قَالَ ‏"‏ اقْتُلُوهُ ‏"‏ ‏.‏ ثُمَّ دَفَعَهُ إِلَى فِتْيَةٍ مِنْ قُرَيْشٍ لِيَقْتُلُوهُ مِنْهُمْ عَبْدُ اللَّهِ بْنُ الزُّبَيْرِ - وَكَانَ يُحِبُّ الإِمَارَةَ - فَقَالَ أَمِّرُونِي عَلَيْكُمْ ‏.‏ فَأَمَّرُوهُ عَلَيْهِمْ فَكَانَ إِذَا ضَرَبَ ضَرَبُوهُ حَتَّى قَتَلُوهُ ‏.‏\hadithno{4977}\hadithgrade{Abu Ghuddah: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Al-Harith bin Hatib that a thief was brought to the Messenger of Allah and he said:"Kill him." They said: "O Messenger of Allah, he only stole (something)." He said: "Kill him." They said: "O Messenger of Allah, he only stole (something)." He said: "Cut off his hand." Then he stole again, and his foot was cut off. Then he stole at the time of Abu Bakr, untilo all his extremities had been cut off. Then he stole a fifth time, and Abu Bakr, may Allah be pleased with him, said: "The Messenger of Allah knew better about him when he said: 'Kill him."' Then he handed him over to some young men of Quraish to kill him, among whom was 'Abdullah bin Az-Zubair who liked to be in a position of leadership. He said: "Put me in charge of them," so they put him in charge of them and when he struck him, they would strike him, until they killed him}}
\hadithdefcmd{nasai}{4978}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عُبَيْدِ بْنِ عَقِيلٍ، قَالَ حَدَّثَنَا جَدِّي، قَالَ حَدَّثَنَا مُصْعَبُ بْنُ ثَابِتٍ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ جِيءَ بِسَارِقٍ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ اقْتُلُوهُ ‏"‏ ‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ إِنَّمَا سَرَقَ ‏.‏ قَالَ ‏"‏ اقْطَعُوهُ ‏"‏ ‏.‏ فَقُطِعَ ثُمَّ جِيءَ بِهِ الثَّانِيَةَ فَقَالَ ‏"‏ اقْتُلُوهُ ‏"‏ ‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ إِنَّمَا سَرَقَ ‏.‏ قَالَ ‏"‏ اقْطَعُوهُ ‏"‏ ‏.‏ فَقُطِعَ فَأُتِيَ بِهِ الثَّالِثَةَ فَقَالَ ‏"‏ اقْتُلُوهُ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ إِنَّمَا سَرَقَ ‏.‏ فَقَالَ ‏"‏ اقْطَعُوهُ ‏"‏ ‏.‏ ثُمَّ أُتِيَ بِهِ الرَّابِعَةَ فَقَالَ ‏"‏ اقْتُلُوهُ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ إِنَّمَا سَرَقَ ‏.‏ قَالَ ‏"‏ اقْطَعُوهُ ‏"‏ ‏.‏ فَأُتِيَ بِهِ الْخَامِسَةَ قَالَ ‏"‏ اقْتُلُوهُ ‏"‏ ‏.‏ قَالَ جَابِرٌ فَانْطَلَقْنَا بِهِ إِلَى مِرْبَدِ النَّعَمِ وَحَمَلْنَاهُ فَاسْتَلْقَى عَلَى ظَهْرِهِ ثُمَّ كَشَّرَ بِيَدَيْهِ وَرِجْلَيْهِ فَانْصَدَعَتِ الإِبِلُ ثُمَّ حَمَلُوا عَلَيْهِ الثَّانِيَةَ فَفَعَلَ مِثْلَ ذَلِكَ ثُمَّ حَمَلُوا عَلَيْهِ الثَّالِثَةَ فَرَمَيْنَاهُ بِالْحِجَارَةِ فَقَتَلْنَاهُ ثُمَّ أَلْقَيْنَاهُ فِي بِئْرٍ ثُمَّ رَمَيْنَا عَلَيْهِ بِالْحِجَارَةِ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ وَهَذَا حَدِيثٌ مُنْكَرٌ وَمُصْعَبُ بْنُ ثَابِتٍ لَيْسَ بِالْقَوِيِّ فِي الْحَدِيثِ وَاللَّهُ تَعَالَى أَعْلَمُ ‏.‏\hadithno{4978}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:"A thief was brought to the Messenger of Allah and he said: 'Kill him.' They said: 'O Messenger of Allah, he only stole.' He said: 'Cut off (his hand).' So his hand was cut off. Then he was brought a second time and he said: 'Kill him.' They said; 'O Messenger of Allah, he only stole.' He said: 'Cut off (his foot).' So his foot was cut off. He was brought to him a third time and he said: 'Kill him.' They said: 'O Messenger of Allah, he only stole. He said: 'Cut off (his other hand).' Then he was brought to him a fourth time and he said: Kill him.' They said: 'O Messenger of Allah, he only stole.' He said: 'Cut off (his other foot).' He was brought to him a fifth time and he said: "So we took him to an animal pen and attacked him. He lay down on his back then waved his arms and legs (in the air), and the camels ran away. Then they attacked him a second time and he did the same thing, then they attacked him a third time, and we threw stones at him and killed him, then we threw him into a well and threw stones on top of him." (Hasan) Abu 'Abdur-Rahman (An-Nasai) said: This Hadith is Munkar, Musab bin Thabit is not strong in Hadith}}
\hadithdefcmd{nasai}{4979}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنِي بَقِيَّةُ، قَالَ حَدَّثَنِي نَافِعُ بْنُ يَزِيدَ، قَالَ حَدَّثَنِي حَيْوَةُ بْنُ شُرَيْحٍ، عَنْ عَيَّاشِ بْنِ عَبَّاسٍ، عَنْ جُنَادَةَ بْنِ أَبِي أُمَيَّةَ، قَالَ سَمِعْتُ بُسْرَ بْنَ أَبِي أَرْطَاةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تُقْطَعُ الأَيْدِي فِي السَّفَرِ ‏"‏ ‏.‏\hadithno{4979}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Junadah bin Abi Umayyah said:"I heard Busr bin Abi Artah say: 'I heard the Messenger of Allah say: Hand should not be cut off while traveling}}
\hadithdefcmd{nasai}{4980}{أَخْبَرَنَا الْحَسَنُ بْنُ مُدْرِكٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ حَمَّادٍ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عُمَرَ، - وَهُوَ ابْنُ أَبِي سَلَمَةَ - عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا سَرَقَ الْعَبْدُ فَبِعْهُ وَلَوْ بِنَشٍّ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ عُمَرُ بْنُ أَبِي سَلَمَةَ لَيْسَ بِالْقَوِيِّ فِي الْحَدِيثِ ‏.‏\hadithno{4980}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Prophet said:"If a slave steals, then sell him, even for half price." (Hasan) Abu 'Abdur-Rahman (An-Nasai) said: 'Umar bin Abi Salamah is not strong in Hadith}}
\hadithdefcmd{nasai}{4981}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ عَطِيَّةَ، أَنَّهُ أَخْبَرَهُ قَالَ كُنْتُ فِي سَبْىِ قُرَيْظَةَ وَكَانَ يُنْظَرُ فَمَنْ خَرَجَ شِعْرَتُهُ قُتِلَ وَمَنْ لَمْ تَخْرُجِ اسْتُحْيِيَ وَلَمْ يُقْتَلْ ‏.‏\hadithno{4981}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Atiyyah said:'I was among the prisoners of Quraizah; we were examined, and whoever had grown (pubic) hair was killed, and whoever had not grown hair, he was allowed to live and was not killed}}
\hadithdefcmd{nasai}{4982}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ أَبِي بَكْرِ بْنِ عَلِيٍّ، عَنِ الْحَجَّاجِ، عَنْ مَكْحُولٍ، عَنِ ابْنِ مُحَيْرِيزٍ، قَالَ سَأَلْتُ فَضَالَةَ بْنَ عُبَيْدٍ عَنْ تَعْلِيقِ، يَدِ السَّارِقِ فِي عُنُقِهِ قَالَ سُنَّةٌ قَطَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَ سَارِقٍ وَعَلَّقَ يَدَهُ فِي عُنُقِهِ ‏.‏\hadithno{4982}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn Muhairiz said; "I asked Fadalah bin 'Ubaid about hanging the hand (of the thief) from his neck, and he said:'It is Sunnah. The Messenger of Allah cut off a thief's hand then hung it from his neck."'(Daif)}}
\hadithdefcmd{nasai}{4983}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنِي عُمَرُ بْنُ عَلِيٍّ الْمُقَدَّمِيُّ، قَالَ حَدَّثَنَا الْحَجَّاجُ، عَنْ مَكْحُولٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ مُحَيْرِيزٍ، قَالَ قُلْتُ لِفَضَالَةَ بْنِ عُبَيْدٍ أَرَأَيْتَ تَعْلِيقَ الْيَدِ فِي عُنُقِ السَّارِقِ مِنَ السُّنَّةِ هُوَ قَالَ نَعَمْ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِسَارِقٍ فَقَطَعَ يَدَهُ وَعَلَّقَهُ فِي عُنُقِهِ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ الْحَجَّاجُ بْنُ أَرْطَاةَ ضَعِيفٌ وَلاَ يُحْتَجُّ بِحَدِيثِهِ ‏.‏\hadithno{4983}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdur-Rahman bin Muhairiz said:"I said to Fadalah bin 'Ubaid: 'Do you think that hanging the hand from the thief's neck is Sunnah?' He said: 'Yes; a thief was brought to the Messenger of Allah and he cut off his hand and hung it from his neck."' (Daif) Abu 'Abdur-Rahman (An-Nasai) said; Al-Hajjaj bin Artah is weak, his narrations are not used as proof}}
\hadithdefcmd{nasai}{4984}{أَخْبَرَنِي عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا حَسَّانُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا الْمُفَضَّلُ بْنُ فَضَالَةَ، عَنْ يُونُسَ بْنِ يَزِيدَ، قَالَ سَمِعْتُ سَعْدَ بْنَ إِبْرَاهِيمَ، يُحَدِّثُ عَنِ الْمِسْوَرِ بْنِ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُغَرَّمُ صَاحِبُ سَرِقَةٍ إِذَا أُقِيمَ عَلَيْهِ الْحَدُّ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ وَهَذَا مُرْسَلٌ وَلَيْسَ بِثَابِتٍ ‏.‏\hadithno{4984}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Abdur-Rahman bin 'Awf that the Messenger of Allah said:"The thief is not to be penalized (financially) if the Hadd punishment is carried out on him." (Daif) Abu 'Abdur-Rahman (An-Nasai) said: This is Mursal and it is not confirmed}}
